/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_EQ_HPP_
#define _HEAVY_CONTEXT_WSTD_EQ_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvControlUnop.h"
#include "HvSignalBiquad.h"
#include "HvMath.h"
#include "HvControlCast.h"
#include "HvControlSystem.h"
#include "HvControlBinop.h"
#include "HvControlSlice.h"
#include "HvSignalLine.h"
#include "HvSignalVar.h"
#include "HvControlIf.h"
#include "HvControlVar.h"

class Heavy_WSTD_EQ : public HeavyContext {

 public:
  Heavy_WSTD_EQ(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_EQ();

  const char *getName() override { return "WSTD_EQ"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        HIGH = 0xC9CE7B11, // High
        LOW = 0x87744544, // Low
        MID = 0xBFDC48B6, // Mid
        MID_FREQ = 0x59CF21AC, // Mid_Freq
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_xWf7UZvh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_01G6K7PO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_n8DxDHoG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_CG738qBI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_OlNTwTxv_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_egSlUls3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1ykegNop_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_8IFDensR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_MiRisBSP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ZtGNHprr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_3Mp2fqk5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9OxmMT6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J7aBfiIo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_erysw9wz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hXaHXi7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7vbwS1DV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Bc67Dqtt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LtPwc845_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mR7JdZfI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qw0OqjJ3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_tGtX0fQI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_E7gvlClQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ic3b1J61_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F9X6fBP4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tL7Fc1LN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fe56ocBE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9f7vqvvi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D5Zrot9v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Y5r2kgZz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5BjHHkYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7GsSDsRM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_hic5jfvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qpWhrVXf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_MPpp3OSa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_tMvopFS5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_78N28mEO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VMqF0BTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RkveuWPt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8FBSWVbD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IjYIHIRg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WX9rdCdj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HekgS0Si_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8FUdM7Mq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_ceDSQN79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uW3zsEnD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tKnSKYjN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z0wTmNpr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6X4D4a5j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4jrydKXt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EWLp4utH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3hxA6Gwd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TLyEhk9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DqhTUj4a_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_06UpQNKN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_5fNhFnIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_oInvvxgE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_5sOKHeFG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_voKKj9La_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_N3YkwDuA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vlQhIEwS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eux71IMj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SMKLVit8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2IwRdpB4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kExfhHxI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vHb36GFB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9QqbpI1e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_mML11FZB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XU4c4azU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h6ckxDt4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OYzskXXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TO8JiULs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_b2SP1GE5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yEV01PVq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZuSa0dDg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ziJH9D3X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nlVRgIsN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_g9gwh5P3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_eu4bI2kJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_jXcnRuar_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_N5TWDGhE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_wHOpbdTl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_JJnopD1Y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_TwTlvTb4_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_9ITnYWaA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IFEA1uAM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Uupftamy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ADX3RKD2_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DyAKmpfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E1mSgL7l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QrbYjDpO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_2zCfPnsG_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_1yVWGiP1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_vZBPF4Bj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_L46ZrBQv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_blo0l4lg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zZhCdl9P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_crHrnvbB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_L7saDiuM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Lw2OEt2j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_mV0tCJZX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_Dk5oDqXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_oEkaUV8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_T81N6fnh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fFeinfwh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SlRIigtp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QyF7xYfS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fYYFxdnc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_FlHIleNX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_jqCXKCHz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_d8b2CSUJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zl2UH28t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uq8gv2xd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NPDU2Sb9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zPA53lWs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mSYVLC6X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_VbV0jT8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9dIkphm8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oZUGsFnF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_fPWH4OYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZIadLj5h_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gZnYeCH1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_uXZRIPlY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zPkWF2FJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CHLZ3cJ1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_O0MGZfAn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_YAs4T9ih_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_c3Kq46yA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_1xWdOGH4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Bj1uyKgX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_mXLeUi4e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_CisHBR6b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_odL3eP9q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qaAAV8rG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RcLBBhrh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bZN3kUiv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0VvDN6RJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_kUQSg8EX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4ptPGOQ5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7CHgnqkW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_EgyuTLdY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NXkwhC2L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n8LmFDbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Gq7H4ICc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eIU5Q2eK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E2JDWhMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_r06WDH7J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LvsI8BUh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_GVEx8FBr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tilrETLj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P3IuUYoQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_clQFyNq1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YL0vjNoJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6j0cevBG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_TkgK093t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KWRSI4Sm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ALTiJ7py_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7R0SoUJc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_gBKsAU59_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_cKywY5hN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_aDdzYCQW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CjsjGHFH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Aak6g6Gf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dHQiC2v9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_i7QXvhK6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PZl0V7qT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_N8z8X412_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JZqO4E96_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DeMutXeR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Hl0TPVB0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mjruYLUm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_J8GNcLlO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_o6mx2bPz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L5IppPZ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6MiiX54U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xwI4S32c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_T3e6w7ra_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_mzaHSRoZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_TAMwugwW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FCJrbapa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qGS9QHFW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_i6EfdFiX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_bASQJI68_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_7Q7ZVItO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fDkaQdbe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9sTT6UOv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hMsiR1mW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_7b3Z37u7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ZTsqht0A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_SrTsdKZl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AEbfpOS3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yW75zqJX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PRh2xAx2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Qz9LTSpg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_KVv93Gfw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XXn1988S_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_G3bNxZgN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4ZGSbfl0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_rsHRbdGv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ZHzzi2xG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O1FVKzbk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xbrBgkzn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PfMOEbHp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HX94NBQb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GDXQ7khd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kQNnEpJb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PJ8YJXa4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2x8gGbSm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_saXfjKXE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EjqVKa1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HiC2P7Rn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zMmcVhWo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FnvyFoha_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rqVgaXDx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oQQxa3kU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_qFHtbAzk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_9m0yj9MJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3FcOfVt2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZBMT5G6I_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r2xmLK1j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IofhCytB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8vAjFFU1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EN9yKeFN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_C2SDqdwB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_qZaP4rUN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FElb5PhA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hrVgFfGN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_wI2CO59F_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3V1LU2KL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nLfygqic_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FF1SFKsI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_07PGP0AF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nZI0TFoR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_lErl8wZT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Cb7Ogbdi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_aDLBtaIc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_wBfW2E9O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Lc9cVYoW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_chBcsKBc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ILGFlZVW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_ftNtY57q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_McPw1wMk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KTtZnPhL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PHiFo1EA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p8aPPuna_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j3QWhG7r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hcw8Pj6e_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrXb3uYm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pBS4wjfH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ouZuXE4b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gNcydmKX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UNqLd9g6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_e8Xx62VS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2v6ANncB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_a3OG2jhr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_3iUEOTox_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jc6ltAiY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BrpNMicc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6LzQCgDN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_phr8qvXx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VVJk3jcP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VDb7FvDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g2APUdQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fMoPt7OT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rLJt5Ujv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Y6sqa0Om_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_6zZCjISx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_6ISbK9nN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Nb0o6iPr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_tubFKxVC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_ktyj4tTu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_n4Da5ihH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qDjrWnYd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_U7wlSeMm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xL497Kso_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Df6sdqNm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zx4OUGTg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_xezi2IAP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wz2zO0N8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jrbeKzTT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Kg5ldU6j_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XIgLBnAI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_qjGzI0GC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GTxZ7n1M_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ferUCm4c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LMYTsD1U_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_A8PlNSvn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ennpCmpv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_HhtVHvX4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gtZrBzWD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_yujChPPB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CDwQU9su_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_BiQHxYyM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_GeEzdnn6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_E1iA1G1B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_1qva2u6R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5eDDB7Wk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Et1jwfOb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Z67sXZYv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_MGp7Ucss_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IttRkvni_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_h2TkK2qB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ht1WVFE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5MPXjs1y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UQDNyvwK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QIlETFvd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_hDsZiQrA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_TjkDJmKt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_f7iSfwDi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mdOfBpjH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fhmm1b5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8Mb3RXZ8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LwWJLdw4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_7NybhW99_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_E3pd0BaY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6K7CHKPM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_imZFQ7kG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_2Xwquonb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_13kY7xFX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pGuB1Abf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_IvOCwCjO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g09f30X2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ABFeJJ4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pkPk7JUx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u5krVbWi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_u4nKsYC7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_JWsUpbL5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_vGRv2tze_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_g8H2YY8R_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cz8tLaDt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aI8Tezfp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2sfIoU6B_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yR0fmpzQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YY3aVqXs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MDc1fj3O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_HN7L9eR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_VsJNFQ38_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_esUH2LZt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SmxXoIoq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_QJ0o1Mhy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_T4j6McVc_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_j54eEfWU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_QHrEB6xm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Gv7y5Xbg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LH6eigdx_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_qwki8XY7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bvpBz6Gu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_2sgUBoWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_ETvZrjhr_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_IG16YcMO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_kOcqlulH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_UzNM7pYs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_MSyPzTbP_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_5LavL4mZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_35Hg1E5b_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NXY9kEKx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uzRqW2WD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_c7X3O1C5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_0nIZa7xg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_KCTUSGwk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GY8gAXZw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SFEwzws8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fjrWZ2wj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nJvC44Is_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5EqO3mLF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6LZ0hDqv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8hijTCki_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L8OmIhT8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pz9W3xqI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_TnIRrliW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_nEIMV5Mc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_n1F5q0I1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qoLGnecd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Ie7yqht7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4uE2uZwI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RpAQVHUA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PK5dvQ6G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tWUAOIVG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QXYZqxc4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yAt75JiA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_2KikxoZe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_I47DIXMN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iiVpZJph_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zsUKEb76_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_zdJazS02_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_FlfPxyC1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Ea2YNFY8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3TuTX6KM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lS8Uz41X_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_YFpS446s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Y3dqrdqA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_97RiOha0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_wb5SGBQK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_uOfHyBCx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oxNF8Fp6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p5HFPYw5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cunFmX14_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_F1ZFJxmX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G07FnVHM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_5QhIo8QK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xFmYMSwR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3rj1PVUp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_MYKXbix2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_gQiC1v8p_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_W39B8ON7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_t9Sx512z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_lfdiRRkQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_P1cbaJ7G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_cxTM3GIP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_OWH28gTQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JlJJOj9x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_uk0ZHmoF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hhl9a4eT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9u8bsIWV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lLdQoIE4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_YPXEPceG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_jna5qhMx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9VMOBUVV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_eXGsdwDe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_7WGxeMfB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_aHVLKC8d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_kHG47VDk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_cT2iUPHx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_nspQ5PVI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g73q3Dun_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_v0IAk2td_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_PsNDykz6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_hBQgRfWB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_iJzB17la_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g0KU0Kjj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wsj28iB8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tKZTP88Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jY7cTmik_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xYpYMzrN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_B1rZuNyw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XVxhhTSF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OYanjTAt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uPZXWPWX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_zd59JvM1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_PqhRmMpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Fly1yzJq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_UPxXuWR2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_x7lmrZCg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Rh6oqgtM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_QS7oUMNR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xDoe9NvZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qygkkjWu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yrYM0rUM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zAJyA9yp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r9MsNj5P_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pVnGzff3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Rn46xoJL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mrKkGhB7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_de7Tm6Jq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zvMOCBLA_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_mgPasiUr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_tMAvOG5n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_XbRygMti_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4YfKmNYO_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8EqfbjrL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Whd3x6c6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_9Ai3RRF2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LN6wBRN5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_WGDbwMu9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_p6vgK9tP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_smWmTwh8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ssLE7xSI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fwTacwTX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_N8EaXkFb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_xV0EJKFi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_IlWzwxcb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_x24lPDGD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4z4saje5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_8d73lgbh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DBcVbrQ0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UBDn9OKV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_EJy3obJe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_GQRys0Bk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XQr3qUd2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mjmLQY8c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XLwwgmlP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UZbpDP2E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6fvEYUCb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Jq8JatfX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Tj0vsmBB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h9lrMtMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xTRY79fN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6zipB14D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ybUmoPUV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_g17Z18Bb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KugwbYqG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YzNEm1jm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LdjQjgoP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_q2ciezr0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_E6r3I2TX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_dOWLAjsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_NZN9fqe6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_6fAKNjmj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_gVgKRYyC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_nbcS2i1s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_Sq43a3mG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_sFrKhoPP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_suWATZXI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RxcOy1LX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_YMzqI3Xh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_UEuV2Yau_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_6gtCftrG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0VqoNtoc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_zobaHYH1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AiPkpFjX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bKDaFmr5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9yRG6AFr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_F5laAcl6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_85VjVMCK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_O2eEn830_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_R6J1oeg7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_plNZgmEa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_piL8sidk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_2RC5P5m1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_u2B4gWKM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EiKZ8cFQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CMp5N4eh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_qTPsmxhM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ukqWXPaH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bszwisbi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RU6XGBIY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yqxGNDpQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1g03iaMu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KYp0bA6d_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_7qqN8heI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1A1ef6dV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Efe9vPp8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hioccl7c_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_5KeQMvM0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QWCp7tZb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_OXkWP8Cg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_nRNQUTVw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_1pHyu2zH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JhixydJl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_6wPlivqT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PwT6U3QV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jEAZI9bU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_K1NuEw5k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_5R954XtI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_42vSJ2BE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_EsZoqUpI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3zyuwkjg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pzaJPnFM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3Dur9i1O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_M2litCOk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_OBCdIMwd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hLfXSO79_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sKOIdPwz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_qD707uNE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_R0V7U4Bg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_fHRAYtoR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pxhbOd5g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bDG4gBAp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Qp0Me2As_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_LxTANZD4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_mP3W0opV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_pMrL1FYe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zFGQv2q2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_T4WcS9zi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_wpmw7gzD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_bWWCNyDh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_zC4hqhfQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_HLQfaIb3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_j5UHVjtT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_hvqCd7Qh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XOTWu2Lk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_sLx33Q4n_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_Lyejhmvr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_5r1SmZwm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_s80JItwN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_iY3f9nll_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_b4hTE4zN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_VpcZjU5G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_ySiLqefx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_JNx0OaIt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_eSVrN1i8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_G6i3dsJC_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_uKPIeTTN;
  SignalLine sLine_wnzkx90x;
  SignalLine sLine_U4e6Vp51;
  SignalLine sLine_epQbvpgc;
  SignalLine sLine_ZX8PNt0i;
  SignalBiquad sBiquad_s_MfW9JfUK;
  SignalLine sLine_OG6LsHJq;
  SignalLine sLine_uv4xm7Hx;
  SignalLine sLine_mOppRAfI;
  SignalLine sLine_jOjrOArd;
  SignalBiquad sBiquad_s_IXgJlKeF;
  SignalLine sLine_rInwl1Rj;
  SignalLine sLine_W2FWSlaA;
  SignalLine sLine_OD3BumRf;
  SignalLine sLine_sfJd1PV4;
  SignalLine sLine_UyQ76W9B;
  SignalBiquad sBiquad_s_mY4z2avg;
  SignalLine sLine_gfl1TidP;
  SignalLine sLine_2UKSoCYt;
  SignalLine sLine_SeC5DtSd;
  SignalLine sLine_KOD0zgCc;
  SignalLine sLine_IWkqPl0x;
  SignalBiquad sBiquad_s_dgTIEzGe;
  SignalLine sLine_ugu5BkdW;
  SignalLine sLine_URLplXrp;
  SignalLine sLine_5vfYu8yo;
  SignalLine sLine_jjUIYe6a;
  SignalBiquad sBiquad_s_f8zli3sR;
  SignalLine sLine_QKRYGvSF;
  SignalLine sLine_ERvQ8CKz;
  SignalLine sLine_v1n7YWVC;
  SignalLine sLine_CCkpORTi;
  SignalLine sLine_BMQraApz;
  SignalBiquad sBiquad_s_BzDxoZ4N;
  ControlVar cVar_xWf7UZvh;
  ControlVar cVar_01G6K7PO;
  ControlVar cVar_n8DxDHoG;
  ControlVar cVar_CG738qBI;
  ControlSlice cSlice_egSlUls3;
  ControlVar cVar_1ykegNop;
  ControlVar cVar_MiRisBSP;
  ControlIf cIf_ZtGNHprr;
  ControlIf cIf_3Mp2fqk5;
  ControlBinop cBinop_J7aBfiIo;
  ControlBinop cBinop_erysw9wz;
  ControlBinop cBinop_Bc67Dqtt;
  ControlBinop cBinop_LtPwc845;
  ControlBinop cBinop_Qw0OqjJ3;
  ControlIf cIf_tGtX0fQI;
  ControlBinop cBinop_E7gvlClQ;
  ControlBinop cBinop_ic3b1J61;
  ControlBinop cBinop_tL7Fc1LN;
  ControlBinop cBinop_fe56ocBE;
  ControlBinop cBinop_9f7vqvvi;
  ControlVar cVar_hic5jfvC;
  ControlIf cIf_qpWhrVXf;
  ControlIf cIf_MPpp3OSa;
  ControlBinop cBinop_78N28mEO;
  ControlBinop cBinop_VMqF0BTl;
  ControlBinop cBinop_IjYIHIRg;
  ControlBinop cBinop_WX9rdCdj;
  ControlBinop cBinop_8FUdM7Mq;
  ControlIf cIf_ceDSQN79;
  ControlBinop cBinop_uW3zsEnD;
  ControlBinop cBinop_tKnSKYjN;
  ControlBinop cBinop_6X4D4a5j;
  ControlBinop cBinop_4jrydKXt;
  ControlBinop cBinop_EWLp4utH;
  ControlVar cVar_5fNhFnIP;
  ControlIf cIf_oInvvxgE;
  ControlIf cIf_5sOKHeFG;
  ControlBinop cBinop_N3YkwDuA;
  ControlBinop cBinop_vlQhIEwS;
  ControlBinop cBinop_2IwRdpB4;
  ControlBinop cBinop_kExfhHxI;
  ControlBinop cBinop_9QqbpI1e;
  ControlIf cIf_mML11FZB;
  ControlBinop cBinop_XU4c4azU;
  ControlBinop cBinop_h6ckxDt4;
  ControlBinop cBinop_TO8JiULs;
  ControlBinop cBinop_b2SP1GE5;
  ControlBinop cBinop_yEV01PVq;
  ControlIf cIf_eu4bI2kJ;
  ControlSlice cSlice_N5TWDGhE;
  ControlVar cVar_wHOpbdTl;
  ControlSlice cSlice_9ITnYWaA;
  ControlVar cVar_IFEA1uAM;
  ControlSlice cSlice_DyAKmpfH;
  ControlVar cVar_E1mSgL7l;
  ControlSlice cSlice_1yVWGiP1;
  ControlVar cVar_vZBPF4Bj;
  ControlBinop cBinop_fFeinfwh;
  ControlBinop cBinop_QyF7xYfS;
  ControlBinop cBinop_fYYFxdnc;
  ControlBinop cBinop_d8b2CSUJ;
  ControlBinop cBinop_Zl2UH28t;
  ControlBinop cBinop_Uq8gv2xd;
  ControlBinop cBinop_NPDU2Sb9;
  ControlBinop cBinop_zPA53lWs;
  ControlVar cVar_mSYVLC6X;
  ControlBinop cBinop_VbV0jT8d;
  ControlBinop cBinop_9dIkphm8;
  ControlBinop cBinop_oZUGsFnF;
  ControlBinop cBinop_fPWH4OYO;
  ControlBinop cBinop_ZIadLj5h;
  ControlBinop cBinop_gZnYeCH1;
  ControlBinop cBinop_uXZRIPlY;
  ControlBinop cBinop_CHLZ3cJ1;
  ControlVar cVar_O0MGZfAn;
  ControlVar cVar_YAs4T9ih;
  ControlBinop cBinop_qaAAV8rG;
  ControlBinop cBinop_RcLBBhrh;
  ControlBinop cBinop_bZN3kUiv;
  ControlBinop cBinop_kUQSg8EX;
  ControlBinop cBinop_4ptPGOQ5;
  ControlBinop cBinop_7CHgnqkW;
  ControlBinop cBinop_EgyuTLdY;
  ControlBinop cBinop_NXkwhC2L;
  ControlBinop cBinop_n8LmFDbh;
  ControlBinop cBinop_CjsjGHFH;
  ControlBinop cBinop_dHQiC2v9;
  ControlBinop cBinop_i7QXvhK6;
  ControlBinop cBinop_JZqO4E96;
  ControlBinop cBinop_DeMutXeR;
  ControlBinop cBinop_Hl0TPVB0;
  ControlBinop cBinop_mjruYLUm;
  ControlBinop cBinop_J8GNcLlO;
  ControlBinop cBinop_o6mx2bPz;
  ControlBinop cBinop_L5IppPZ0;
  ControlBinop cBinop_xwI4S32c;
  ControlVar cVar_T3e6w7ra;
  ControlVar cVar_mzaHSRoZ;
  ControlVar cVar_TAMwugwW;
  ControlBinop cBinop_9sTT6UOv;
  ControlBinop cBinop_hMsiR1mW;
  ControlBinop cBinop_7b3Z37u7;
  ControlBinop cBinop_SrTsdKZl;
  ControlBinop cBinop_AEbfpOS3;
  ControlBinop cBinop_yW75zqJX;
  ControlBinop cBinop_PRh2xAx2;
  ControlBinop cBinop_Qz9LTSpg;
  ControlBinop cBinop_zMmcVhWo;
  ControlBinop cBinop_rqVgaXDx;
  ControlBinop cBinop_oQQxa3kU;
  ControlBinop cBinop_3FcOfVt2;
  ControlBinop cBinop_ZBMT5G6I;
  ControlBinop cBinop_r2xmLK1j;
  ControlBinop cBinop_IofhCytB;
  ControlBinop cBinop_8vAjFFU1;
  ControlBinop cBinop_C2SDqdwB;
  ControlBinop cBinop_FElb5PhA;
  ControlBinop cBinop_hrVgFfGN;
  ControlBinop cBinop_3V1LU2KL;
  ControlBinop cBinop_nLfygqic;
  ControlBinop cBinop_FF1SFKsI;
  ControlBinop cBinop_nZI0TFoR;
  ControlVar cVar_lErl8wZT;
  ControlVar cVar_Cb7Ogbdi;
  ControlVar cVar_aDLBtaIc;
  ControlBinop cBinop_KTtZnPhL;
  ControlBinop cBinop_PHiFo1EA;
  ControlBinop cBinop_p8aPPuna;
  ControlBinop cBinop_hcw8Pj6e;
  ControlBinop cBinop_jrXb3uYm;
  ControlBinop cBinop_pBS4wjfH;
  ControlBinop cBinop_ouZuXE4b;
  ControlBinop cBinop_gNcydmKX;
  ControlBinop cBinop_UNqLd9g6;
  ControlBinop cBinop_g2APUdQK;
  ControlBinop cBinop_rLJt5Ujv;
  ControlBinop cBinop_Y6sqa0Om;
  SignalVarf sVarf_mVOkfkPc;
  SignalVarf sVarf_6hX8dSHG;
  SignalVarf sVarf_wXG7r5LV;
  ControlSlice cSlice_6ISbK9nN;
  ControlVar cVar_Nb0o6iPr;
  ControlVar cVar_ktyj4tTu;
  ControlIf cIf_n4Da5ihH;
  ControlIf cIf_qDjrWnYd;
  ControlBinop cBinop_xL497Kso;
  ControlBinop cBinop_Df6sdqNm;
  ControlBinop cBinop_Wz2zO0N8;
  ControlBinop cBinop_jrbeKzTT;
  ControlBinop cBinop_XIgLBnAI;
  ControlIf cIf_qjGzI0GC;
  ControlBinop cBinop_GTxZ7n1M;
  ControlBinop cBinop_ferUCm4c;
  ControlBinop cBinop_A8PlNSvn;
  ControlBinop cBinop_ennpCmpv;
  ControlBinop cBinop_HhtVHvX4;
  ControlVar cVar_GeEzdnn6;
  ControlIf cIf_E1iA1G1B;
  ControlIf cIf_1qva2u6R;
  ControlBinop cBinop_Et1jwfOb;
  ControlBinop cBinop_Z67sXZYv;
  ControlBinop cBinop_h2TkK2qB;
  ControlBinop cBinop_ht1WVFE4;
  ControlBinop cBinop_UQDNyvwK;
  ControlIf cIf_QIlETFvd;
  ControlBinop cBinop_hDsZiQrA;
  ControlBinop cBinop_TjkDJmKt;
  ControlBinop cBinop_mdOfBpjH;
  ControlBinop cBinop_Fhmm1b5g;
  ControlBinop cBinop_8Mb3RXZ8;
  ControlVar cVar_imZFQ7kG;
  ControlIf cIf_2Xwquonb;
  ControlIf cIf_13kY7xFX;
  ControlBinop cBinop_IvOCwCjO;
  ControlBinop cBinop_g09f30X2;
  ControlBinop cBinop_u5krVbWi;
  ControlBinop cBinop_u4nKsYC7;
  ControlBinop cBinop_vGRv2tze;
  ControlIf cIf_g8H2YY8R;
  ControlBinop cBinop_cz8tLaDt;
  ControlBinop cBinop_aI8Tezfp;
  ControlBinop cBinop_yR0fmpzQ;
  ControlBinop cBinop_YY3aVqXs;
  ControlBinop cBinop_MDc1fj3O;
  ControlIf cIf_QJ0o1Mhy;
  ControlSlice cSlice_j54eEfWU;
  ControlVar cVar_QHrEB6xm;
  ControlSlice cSlice_qwki8XY7;
  ControlVar cVar_bvpBz6Gu;
  ControlSlice cSlice_IG16YcMO;
  ControlVar cVar_kOcqlulH;
  ControlSlice cSlice_5LavL4mZ;
  ControlVar cVar_35Hg1E5b;
  ControlBinop cBinop_6LZ0hDqv;
  ControlBinop cBinop_L8OmIhT8;
  ControlBinop cBinop_pz9W3xqI;
  ControlBinop cBinop_n1F5q0I1;
  ControlBinop cBinop_qoLGnecd;
  ControlBinop cBinop_Ie7yqht7;
  ControlBinop cBinop_4uE2uZwI;
  ControlBinop cBinop_RpAQVHUA;
  ControlVar cVar_PK5dvQ6G;
  ControlBinop cBinop_tWUAOIVG;
  ControlBinop cBinop_QXYZqxc4;
  ControlBinop cBinop_yAt75JiA;
  ControlBinop cBinop_2KikxoZe;
  ControlBinop cBinop_I47DIXMN;
  ControlBinop cBinop_iiVpZJph;
  ControlBinop cBinop_zsUKEb76;
  ControlBinop cBinop_FlfPxyC1;
  ControlVar cVar_Ea2YNFY8;
  ControlVar cVar_3TuTX6KM;
  ControlBinop cBinop_oxNF8Fp6;
  ControlBinop cBinop_p5HFPYw5;
  ControlBinop cBinop_cunFmX14;
  ControlBinop cBinop_G07FnVHM;
  ControlBinop cBinop_5QhIo8QK;
  ControlBinop cBinop_xFmYMSwR;
  ControlBinop cBinop_3rj1PVUp;
  ControlBinop cBinop_MYKXbix2;
  ControlBinop cBinop_gQiC1v8p;
  ControlBinop cBinop_cT2iUPHx;
  ControlBinop cBinop_g73q3Dun;
  ControlBinop cBinop_v0IAk2td;
  ControlBinop cBinop_iJzB17la;
  ControlBinop cBinop_g0KU0Kjj;
  ControlBinop cBinop_Wsj28iB8;
  ControlBinop cBinop_tKZTP88Q;
  ControlBinop cBinop_jY7cTmik;
  ControlBinop cBinop_xYpYMzrN;
  ControlBinop cBinop_B1rZuNyw;
  ControlBinop cBinop_OYanjTAt;
  ControlVar cVar_uPZXWPWX;
  ControlVar cVar_zd59JvM1;
  ControlVar cVar_PqhRmMpu;
  ControlBinop cBinop_qygkkjWu;
  ControlBinop cBinop_yrYM0rUM;
  ControlBinop cBinop_zAJyA9yp;
  ControlBinop cBinop_pVnGzff3;
  ControlBinop cBinop_Rn46xoJL;
  ControlBinop cBinop_mrKkGhB7;
  ControlBinop cBinop_de7Tm6Jq;
  ControlBinop cBinop_zvMOCBLA;
  ControlBinop cBinop_4z4saje5;
  ControlBinop cBinop_DBcVbrQ0;
  ControlBinop cBinop_UBDn9OKV;
  ControlBinop cBinop_XQr3qUd2;
  ControlBinop cBinop_mjmLQY8c;
  ControlBinop cBinop_XLwwgmlP;
  ControlBinop cBinop_UZbpDP2E;
  ControlBinop cBinop_6fvEYUCb;
  ControlBinop cBinop_Tj0vsmBB;
  ControlBinop cBinop_xTRY79fN;
  ControlBinop cBinop_6zipB14D;
  ControlBinop cBinop_g17Z18Bb;
  ControlBinop cBinop_KugwbYqG;
  ControlBinop cBinop_YzNEm1jm;
  ControlBinop cBinop_q2ciezr0;
  ControlVar cVar_E6r3I2TX;
  ControlVar cVar_dOWLAjsr;
  ControlVar cVar_NZN9fqe6;
  ControlBinop cBinop_RxcOy1LX;
  ControlBinop cBinop_YMzqI3Xh;
  ControlBinop cBinop_UEuV2Yau;
  ControlBinop cBinop_0VqoNtoc;
  ControlBinop cBinop_zobaHYH1;
  ControlBinop cBinop_AiPkpFjX;
  ControlBinop cBinop_bKDaFmr5;
  ControlBinop cBinop_9yRG6AFr;
  ControlBinop cBinop_F5laAcl6;
  ControlBinop cBinop_ukqWXPaH;
  ControlBinop cBinop_RU6XGBIY;
  ControlBinop cBinop_yqxGNDpQ;
  SignalVarf sVarf_pXuK8bqv;
  SignalVarf sVarf_WveWzeP0;
  SignalVarf sVarf_QrGv3kR6;
  SignalVarf sVarf_l8XAI5VV;
  SignalVarf sVarf_JW4b0eCX;
  SignalVarf sVarf_conjrBqP;
  SignalVarf sVarf_8mD5mv66;
  SignalVarf sVarf_jun1Y1Bj;
  SignalVarf sVarf_pyrQPrPa;
  ControlVar cVar_1g03iaMu;
  ControlVar cVar_KYp0bA6d;
  ControlBinop cBinop_QWCp7tZb;
  ControlBinop cBinop_OXkWP8Cg;
  ControlBinop cBinop_nRNQUTVw;
  ControlBinop cBinop_JhixydJl;
  ControlBinop cBinop_6wPlivqT;
  ControlBinop cBinop_PwT6U3QV;
  ControlBinop cBinop_jEAZI9bU;
};

#endif // _HEAVY_CONTEXT_WSTD_EQ_HPP_
