/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_EQ.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_EQ *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_EQ_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_EQ));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_EQ(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_EQ_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_EQ();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_EQ::Heavy_WSTD_EQ(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_uKPIeTTN);
  numBytes += sLine_init(&sLine_wnzkx90x);
  numBytes += sLine_init(&sLine_U4e6Vp51);
  numBytes += sLine_init(&sLine_epQbvpgc);
  numBytes += sLine_init(&sLine_ZX8PNt0i);
  numBytes += sBiquad_init(&sBiquad_s_MfW9JfUK);
  numBytes += sLine_init(&sLine_OG6LsHJq);
  numBytes += sLine_init(&sLine_uv4xm7Hx);
  numBytes += sLine_init(&sLine_mOppRAfI);
  numBytes += sLine_init(&sLine_jOjrOArd);
  numBytes += sBiquad_init(&sBiquad_s_IXgJlKeF);
  numBytes += sLine_init(&sLine_rInwl1Rj);
  numBytes += sLine_init(&sLine_W2FWSlaA);
  numBytes += sLine_init(&sLine_OD3BumRf);
  numBytes += sLine_init(&sLine_sfJd1PV4);
  numBytes += sLine_init(&sLine_UyQ76W9B);
  numBytes += sBiquad_init(&sBiquad_s_mY4z2avg);
  numBytes += sLine_init(&sLine_gfl1TidP);
  numBytes += sLine_init(&sLine_2UKSoCYt);
  numBytes += sLine_init(&sLine_SeC5DtSd);
  numBytes += sLine_init(&sLine_KOD0zgCc);
  numBytes += sLine_init(&sLine_IWkqPl0x);
  numBytes += sBiquad_init(&sBiquad_s_dgTIEzGe);
  numBytes += sLine_init(&sLine_ugu5BkdW);
  numBytes += sLine_init(&sLine_URLplXrp);
  numBytes += sLine_init(&sLine_5vfYu8yo);
  numBytes += sLine_init(&sLine_jjUIYe6a);
  numBytes += sBiquad_init(&sBiquad_s_f8zli3sR);
  numBytes += sLine_init(&sLine_QKRYGvSF);
  numBytes += sLine_init(&sLine_ERvQ8CKz);
  numBytes += sLine_init(&sLine_v1n7YWVC);
  numBytes += sLine_init(&sLine_CCkpORTi);
  numBytes += sLine_init(&sLine_BMQraApz);
  numBytes += sBiquad_init(&sBiquad_s_BzDxoZ4N);
  numBytes += cVar_init_f(&cVar_xWf7UZvh, 0.0f);
  numBytes += cVar_init_f(&cVar_01G6K7PO, 0.0f);
  numBytes += cVar_init_f(&cVar_n8DxDHoG, 0.0f);
  numBytes += cVar_init_f(&cVar_CG738qBI, 0.0f);
  numBytes += cSlice_init(&cSlice_egSlUls3, 1, -1);
  numBytes += cVar_init_f(&cVar_1ykegNop, 1337.0f);
  numBytes += cVar_init_f(&cVar_MiRisBSP, 0.0f);
  numBytes += cIf_init(&cIf_ZtGNHprr, false);
  numBytes += cIf_init(&cIf_3Mp2fqk5, false);
  numBytes += cBinop_init(&cBinop_J7aBfiIo, 0.0f); // __pow
  numBytes += cIf_init(&cIf_tGtX0fQI, false);
  numBytes += cBinop_init(&cBinop_tL7Fc1LN, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_fe56ocBE, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_9f7vqvvi, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_hic5jfvC, 0.0f);
  numBytes += cIf_init(&cIf_qpWhrVXf, false);
  numBytes += cIf_init(&cIf_MPpp3OSa, false);
  numBytes += cBinop_init(&cBinop_78N28mEO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_ceDSQN79, false);
  numBytes += cBinop_init(&cBinop_6X4D4a5j, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_4jrydKXt, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_EWLp4utH, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_5fNhFnIP, 0.0f);
  numBytes += cIf_init(&cIf_oInvvxgE, false);
  numBytes += cIf_init(&cIf_5sOKHeFG, false);
  numBytes += cBinop_init(&cBinop_N3YkwDuA, 0.0f); // __pow
  numBytes += cIf_init(&cIf_mML11FZB, false);
  numBytes += cBinop_init(&cBinop_TO8JiULs, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_b2SP1GE5, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_yEV01PVq, -15.0f); // __eq
  numBytes += cIf_init(&cIf_eu4bI2kJ, false);
  numBytes += cSlice_init(&cSlice_N5TWDGhE, 1, -1);
  numBytes += cVar_init_f(&cVar_wHOpbdTl, 0.0f);
  numBytes += cSlice_init(&cSlice_9ITnYWaA, 1, -1);
  numBytes += cVar_init_f(&cVar_IFEA1uAM, 0.0f);
  numBytes += cSlice_init(&cSlice_DyAKmpfH, 1, -1);
  numBytes += cVar_init_f(&cVar_E1mSgL7l, 0.0f);
  numBytes += cSlice_init(&cSlice_1yVWGiP1, 1, -1);
  numBytes += cVar_init_f(&cVar_vZBPF4Bj, 0.313f);
  numBytes += cBinop_init(&cBinop_QyF7xYfS, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_fYYFxdnc, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_mSYVLC6X, 0.0f);
  numBytes += cVar_init_f(&cVar_O0MGZfAn, 1337.0f);
  numBytes += cVar_init_f(&cVar_YAs4T9ih, 0.3f);
  numBytes += cBinop_init(&cBinop_RcLBBhrh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_4ptPGOQ5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_7CHgnqkW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_EgyuTLdY, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_NXkwhC2L, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_n8LmFDbh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_dHQiC2v9, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_i7QXvhK6, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_T3e6w7ra, 0.0f);
  numBytes += cVar_init_f(&cVar_mzaHSRoZ, 1337.0f);
  numBytes += cVar_init_f(&cVar_TAMwugwW, 0.313f);
  numBytes += cBinop_init(&cBinop_hMsiR1mW, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AEbfpOS3, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_yW75zqJX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_PRh2xAx2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Qz9LTSpg, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_rqVgaXDx, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_oQQxa3kU, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_lErl8wZT, 0.0f);
  numBytes += cVar_init_f(&cVar_Cb7Ogbdi, 1037.0f);
  numBytes += cVar_init_f(&cVar_aDLBtaIc, 0.4f);
  numBytes += cBinop_init(&cBinop_PHiFo1EA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_jrXb3uYm, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_pBS4wjfH, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_ouZuXE4b, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gNcydmKX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_UNqLd9g6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_mVOkfkPc, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_6hX8dSHG, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_wXG7r5LV, 0.0f, 0.0f, false);
  numBytes += cSlice_init(&cSlice_6ISbK9nN, 1, -1);
  numBytes += cVar_init_f(&cVar_Nb0o6iPr, 1337.0f);
  numBytes += cVar_init_f(&cVar_ktyj4tTu, 0.0f);
  numBytes += cIf_init(&cIf_n4Da5ihH, false);
  numBytes += cIf_init(&cIf_qDjrWnYd, false);
  numBytes += cBinop_init(&cBinop_xL497Kso, 0.0f); // __pow
  numBytes += cIf_init(&cIf_qjGzI0GC, false);
  numBytes += cBinop_init(&cBinop_A8PlNSvn, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_ennpCmpv, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_HhtVHvX4, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_GeEzdnn6, 0.0f);
  numBytes += cIf_init(&cIf_E1iA1G1B, false);
  numBytes += cIf_init(&cIf_1qva2u6R, false);
  numBytes += cBinop_init(&cBinop_Et1jwfOb, 0.0f); // __pow
  numBytes += cIf_init(&cIf_QIlETFvd, false);
  numBytes += cBinop_init(&cBinop_mdOfBpjH, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_Fhmm1b5g, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_8Mb3RXZ8, -15.0f); // __eq
  numBytes += cVar_init_f(&cVar_imZFQ7kG, 0.0f);
  numBytes += cIf_init(&cIf_2Xwquonb, false);
  numBytes += cIf_init(&cIf_13kY7xFX, false);
  numBytes += cBinop_init(&cBinop_IvOCwCjO, 0.0f); // __pow
  numBytes += cIf_init(&cIf_g8H2YY8R, false);
  numBytes += cBinop_init(&cBinop_yR0fmpzQ, 0.0f); // __add
  numBytes += cBinop_init(&cBinop_YY3aVqXs, -15.0f); // __gt
  numBytes += cBinop_init(&cBinop_MDc1fj3O, -15.0f); // __eq
  numBytes += cIf_init(&cIf_QJ0o1Mhy, false);
  numBytes += cSlice_init(&cSlice_j54eEfWU, 1, -1);
  numBytes += cVar_init_f(&cVar_QHrEB6xm, 0.0f);
  numBytes += cSlice_init(&cSlice_qwki8XY7, 1, -1);
  numBytes += cVar_init_f(&cVar_bvpBz6Gu, 0.0f);
  numBytes += cSlice_init(&cSlice_IG16YcMO, 1, -1);
  numBytes += cVar_init_f(&cVar_kOcqlulH, 0.0f);
  numBytes += cSlice_init(&cSlice_5LavL4mZ, 1, -1);
  numBytes += cVar_init_f(&cVar_35Hg1E5b, 0.313f);
  numBytes += cBinop_init(&cBinop_L8OmIhT8, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_pz9W3xqI, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_PK5dvQ6G, 0.0f);
  numBytes += cVar_init_f(&cVar_Ea2YNFY8, 1337.0f);
  numBytes += cVar_init_f(&cVar_3TuTX6KM, 0.3f);
  numBytes += cBinop_init(&cBinop_p5HFPYw5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_5QhIo8QK, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_xFmYMSwR, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_3rj1PVUp, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_MYKXbix2, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_gQiC1v8p, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_g73q3Dun, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_v0IAk2td, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_uPZXWPWX, 0.0f);
  numBytes += cVar_init_f(&cVar_zd59JvM1, 1337.0f);
  numBytes += cVar_init_f(&cVar_PqhRmMpu, 0.313f);
  numBytes += cBinop_init(&cBinop_yrYM0rUM, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_Rn46xoJL, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_mrKkGhB7, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_de7Tm6Jq, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zvMOCBLA, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_DBcVbrQ0, 44100.0f); // __div
  numBytes += cBinop_init(&cBinop_UBDn9OKV, 0.0f); // __mul
  numBytes += cVar_init_f(&cVar_E6r3I2TX, 0.0f);
  numBytes += cVar_init_f(&cVar_dOWLAjsr, 1037.0f);
  numBytes += cVar_init_f(&cVar_NZN9fqe6, 0.4f);
  numBytes += cBinop_init(&cBinop_YMzqI3Xh, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_zobaHYH1, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_AiPkpFjX, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_bKDaFmr5, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_9yRG6AFr, 0.0f); // __mul
  numBytes += cBinop_init(&cBinop_F5laAcl6, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_pXuK8bqv, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WveWzeP0, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_QrGv3kR6, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_l8XAI5VV, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_JW4b0eCX, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_conjrBqP, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_8mD5mv66, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_jun1Y1Bj, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_pyrQPrPa, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1g03iaMu, 5705.6f);
  numBytes += cVar_init_f(&cVar_KYp0bA6d, 313.3f);
  numBytes += cBinop_init(&cBinop_QWCp7tZb, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_OXkWP8Cg, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_nRNQUTVw, 0.0f); // __div
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_EQ::~Heavy_WSTD_EQ() {
  // nothing to free
}

HvTable *Heavy_WSTD_EQ::getTableForHash(hv_uint32_t tableHash) {
  return nullptr;
}

void Heavy_WSTD_EQ::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xC9CE7B11: { // High
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_M2litCOk_sendMessage);
      break;
    }
    case 0x87744544: { // Low
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hLfXSO79_sendMessage);
      break;
    }
    case 0xBFDC48B6: { // Mid
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_OBCdIMwd_sendMessage);
      break;
    }
    case 0x59CF21AC: { // Mid_Freq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_G6i3dsJC_sendMessage);
      break;
    }
    case 0x24295C10: { // 1010-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_R0V7U4Bg_sendMessage);
      break;
    }
    case 0x3649681E: { // 1010-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_fHRAYtoR_sendMessage);
      break;
    }
    case 0xD5A8E74D: { // 1010-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sKOIdPwz_sendMessage);
      break;
    }
    case 0x60D6F65: { // 1010-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_qD707uNE_sendMessage);
      break;
    }
    case 0x37E92263: { // 1010-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pxhbOd5g_sendMessage);
      break;
    }
    case 0x2271964: { // 1069-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_mP3W0opV_sendMessage);
      break;
    }
    case 0xA61C5543: { // 1069-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_LxTANZD4_sendMessage);
      break;
    }
    case 0x1E13C49D: { // 1069-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Qp0Me2As_sendMessage);
      break;
    }
    case 0xE7448D12: { // 1110-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_T4WcS9zi_sendMessage);
      break;
    }
    case 0x5F31ED81: { // 1110-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zFGQv2q2_sendMessage);
      break;
    }
    case 0xC3520438: { // 1110-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_pMrL1FYe_sendMessage);
      break;
    }
    case 0xB2DA8F9A: { // 1151-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_zC4hqhfQ_sendMessage);
      break;
    }
    case 0x668DC2C1: { // 1151-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bWWCNyDh_sendMessage);
      break;
    }
    case 0x413B9F30: { // 1151-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_wpmw7gzD_sendMessage);
      break;
    }
    case 0x845815A0: { // 1163-highvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_hvqCd7Qh_sendMessage);
      break;
    }
    case 0x5CD8AF91: { // 1163-lowvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XOTWu2Lk_sendMessage);
      break;
    }
    case 0x188BB7A0: { // 1163-midfreq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_HLQfaIb3_sendMessage);
      break;
    }
    case 0xE3BB13E4: { // 1163-midq
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_j5UHVjtT_sendMessage);
      break;
    }
    case 0x3693B415: { // 1163-midvol
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_sLx33Q4n_sendMessage);
      break;
    }
    case 0x1A14721E: { // 1222-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_s80JItwN_sendMessage);
      break;
    }
    case 0x446DC164: { // 1222-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_5r1SmZwm_sendMessage);
      break;
    }
    case 0x32F45A8B: { // 1222-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_Lyejhmvr_sendMessage);
      break;
    }
    case 0x1286072C: { // 1263-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_VpcZjU5G_sendMessage);
      break;
    }
    case 0x7902A17C: { // 1263-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_b4hTE4zN_sendMessage);
      break;
    }
    case 0x7A57C19C: { // 1263-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_iY3f9nll_sendMessage);
      break;
    }
    case 0x170C9887: { // 1304-alpha
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_eSVrN1i8_sendMessage);
      break;
    }
    case 0xED0CBA1C: { // 1304-wcos
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_JNx0OaIt_sendMessage);
      break;
    }
    case 0xDA3A818C: { // 1304-wsin
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_ySiLqefx_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_bDG4gBAp_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_EQ::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "High";
        info->hash = 0xC9CE7B11;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 1: {
        info->name = "Low";
        info->hash = 0x87744544;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 2: {
        info->name = "Mid";
        info->hash = 0xBFDC48B6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = -15.0f;
        info->maxVal = 15.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 3: {
        info->name = "Mid_Freq";
        info->hash = 0x59CF21AC;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 313.3f;
        info->maxVal = 5705.6f;
        info->defaultVal = 1337.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 4;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_EQ::cVar_xWf7UZvh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_K1NuEw5k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_01G6K7PO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5R954XtI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_n8DxDHoG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_42vSJ2BE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_CG738qBI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EsZoqUpI_sendMessage(_c, 0, m);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Efe9vPp8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5KeQMvM0_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hioccl7c_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_OlNTwTxv_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_egSlUls3, 0, m, &cSlice_egSlUls3_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ADX3RKD2_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_egSlUls3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_8IFDensR_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_8IFDensR_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_1ykegNop_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_8IFDensR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_8IFDensR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sKOIdPwz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_MiRisBSP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_E7gvlClQ_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_ZtGNHprr, 0, m, &cIf_ZtGNHprr_sendMessage);
}

void Heavy_WSTD_EQ::cIf_ZtGNHprr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ic3b1J61_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_3Mp2fqk5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_mR7JdZfI_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_LtPwc845_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_9OxmMT6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7aBfiIo, HV_BINOP_POW, 0, m, &cBinop_J7aBfiIo_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_J7aBfiIo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tGtX0fQI, 0, m, &cIf_tGtX0fQI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_erysw9wz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_Qw0OqjJ3_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hXaHXi7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Mp2fqk5, 0, m, &cIf_3Mp2fqk5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7vbwS1DV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Bc67Dqtt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Bc67Dqtt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_3Mp2fqk5, 1, m, &cIf_3Mp2fqk5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_LtPwc845_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_erysw9wz_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_mR7JdZfI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_tGtX0fQI, 0, m, &cIf_tGtX0fQI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Qw0OqjJ3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_J7aBfiIo, HV_BINOP_POW, 1, m, &cBinop_J7aBfiIo_sendMessage);
  cMsg_9OxmMT6R_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_tGtX0fQI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_mVOkfkPc, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_E7gvlClQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ZtGNHprr, 1, m, &cIf_ZtGNHprr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ic3b1J61_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fe56ocBE, HV_BINOP_GREATER_THAN, 1, m, &cBinop_fe56ocBE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9f7vqvvi, HV_BINOP_EQ, 1, m, &cBinop_9f7vqvvi_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_F9X6fBP4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_tL7Fc1LN, HV_BINOP_ADD, 0, m, &cBinop_tL7Fc1LN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tL7Fc1LN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7vbwS1DV_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hXaHXi7o_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fe56ocBE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_tGtX0fQI, 1, m, &cIf_tGtX0fQI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9f7vqvvi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D5Zrot9v_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_D5Zrot9v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_mVOkfkPc, m);
}

void Heavy_WSTD_EQ::cCast_Y5r2kgZz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_MiRisBSP, 0, m, &cVar_MiRisBSP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5BjHHkYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F9X6fBP4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_7GsSDsRM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_tL7Fc1LN, HV_BINOP_ADD, 1, m, &cBinop_tL7Fc1LN_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_fe56ocBE, HV_BINOP_GREATER_THAN, 0, m, &cBinop_fe56ocBE_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_9f7vqvvi, HV_BINOP_EQ, 0, m, &cBinop_9f7vqvvi_sendMessage);
}

void Heavy_WSTD_EQ::cVar_hic5jfvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_uW3zsEnD_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_qpWhrVXf, 0, m, &cIf_qpWhrVXf_sendMessage);
}

void Heavy_WSTD_EQ::cIf_qpWhrVXf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_tKnSKYjN_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_MPpp3OSa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_HekgS0Si_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_WX9rdCdj_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_tMvopFS5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_78N28mEO, HV_BINOP_POW, 0, m, &cBinop_78N28mEO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_78N28mEO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ceDSQN79, 0, m, &cIf_ceDSQN79_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_VMqF0BTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_8FUdM7Mq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_RkveuWPt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_IjYIHIRg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8FBSWVbD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MPpp3OSa, 0, m, &cIf_MPpp3OSa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IjYIHIRg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_MPpp3OSa, 1, m, &cIf_MPpp3OSa_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_WX9rdCdj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_VMqF0BTl_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_HekgS0Si_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_ceDSQN79, 0, m, &cIf_ceDSQN79_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8FUdM7Mq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_78N28mEO, HV_BINOP_POW, 1, m, &cBinop_78N28mEO_sendMessage);
  cMsg_tMvopFS5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_ceDSQN79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_g2APUdQK_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rLJt5Ujv_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Y6sqa0Om_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_uW3zsEnD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qpWhrVXf, 1, m, &cIf_qpWhrVXf_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tKnSKYjN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4jrydKXt, HV_BINOP_GREATER_THAN, 1, m, &cBinop_4jrydKXt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EWLp4utH, HV_BINOP_EQ, 1, m, &cBinop_EWLp4utH_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_z0wTmNpr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_6X4D4a5j, HV_BINOP_ADD, 0, m, &cBinop_6X4D4a5j_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6X4D4a5j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_RkveuWPt_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8FBSWVbD_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4jrydKXt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_ceDSQN79, 1, m, &cIf_ceDSQN79_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_EWLp4utH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3hxA6Gwd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_3hxA6Gwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_g2APUdQK_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_rLJt5Ujv_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_Y6sqa0Om_sendMessage);
}

void Heavy_WSTD_EQ::cCast_TLyEhk9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_6X4D4a5j, HV_BINOP_ADD, 1, m, &cBinop_6X4D4a5j_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_4jrydKXt, HV_BINOP_GREATER_THAN, 0, m, &cBinop_4jrydKXt_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_EWLp4utH, HV_BINOP_EQ, 0, m, &cBinop_EWLp4utH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_DqhTUj4a_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_hic5jfvC, 0, m, &cVar_hic5jfvC_sendMessage);
}

void Heavy_WSTD_EQ::cCast_06UpQNKN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_z0wTmNpr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_5fNhFnIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_XU4c4azU_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_oInvvxgE, 0, m, &cIf_oInvvxgE_sendMessage);
}

void Heavy_WSTD_EQ::cIf_oInvvxgE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_h6ckxDt4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_5sOKHeFG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_vHb36GFB_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_kExfhHxI_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_voKKj9La_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_N3YkwDuA, HV_BINOP_POW, 0, m, &cBinop_N3YkwDuA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_N3YkwDuA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mML11FZB, 0, m, &cIf_mML11FZB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vlQhIEwS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_9QqbpI1e_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eux71IMj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5sOKHeFG, 0, m, &cIf_5sOKHeFG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SMKLVit8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_2IwRdpB4_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2IwRdpB4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_5sOKHeFG, 1, m, &cIf_5sOKHeFG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kExfhHxI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_vlQhIEwS_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_vHb36GFB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_mML11FZB, 0, m, &cIf_mML11FZB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9QqbpI1e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_N3YkwDuA, HV_BINOP_POW, 1, m, &cBinop_N3YkwDuA_sendMessage);
  cMsg_voKKj9La_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_mML11FZB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_wXG7r5LV, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_XU4c4azU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_oInvvxgE, 1, m, &cIf_oInvvxgE_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h6ckxDt4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2SP1GE5, HV_BINOP_GREATER_THAN, 1, m, &cBinop_b2SP1GE5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEV01PVq, HV_BINOP_EQ, 1, m, &cBinop_yEV01PVq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_OYzskXXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_TO8JiULs, HV_BINOP_ADD, 0, m, &cBinop_TO8JiULs_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TO8JiULs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SMKLVit8_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eux71IMj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_b2SP1GE5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_mML11FZB, 1, m, &cIf_mML11FZB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yEV01PVq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZuSa0dDg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ZuSa0dDg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wXG7r5LV, m);
}

void Heavy_WSTD_EQ::cCast_ziJH9D3X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OYzskXXS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_nlVRgIsN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_TO8JiULs, HV_BINOP_ADD, 1, m, &cBinop_TO8JiULs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_b2SP1GE5, HV_BINOP_GREATER_THAN, 0, m, &cBinop_b2SP1GE5_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yEV01PVq, HV_BINOP_EQ, 0, m, &cBinop_yEV01PVq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_g9gwh5P3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_5fNhFnIP, 0, m, &cVar_5fNhFnIP_sendMessage);
}

void Heavy_WSTD_EQ::cIf_eu4bI2kJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_6hX8dSHG, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_jXcnRuar_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_N5TWDGhE, 0, m, &cSlice_N5TWDGhE_sendMessage);
      break;
    }
    default: {
      cSwitchcase_TwTlvTb4_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_N5TWDGhE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_JJnopD1Y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_JJnopD1Y_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_wHOpbdTl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_JJnopD1Y_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_JJnopD1Y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_R0V7U4Bg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_TwTlvTb4_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_9ITnYWaA, 0, m, &cSlice_9ITnYWaA_sendMessage);
      break;
    }
    default: {
      cSwitchcase_OlNTwTxv_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_9ITnYWaA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Uupftamy_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Uupftamy_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_IFEA1uAM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Uupftamy_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Uupftamy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pxhbOd5g_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_ADX3RKD2_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DyAKmpfH, 0, m, &cSlice_DyAKmpfH_sendMessage);
      break;
    }
    default: {
      cSwitchcase_2zCfPnsG_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_DyAKmpfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_QrbYjDpO_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_QrbYjDpO_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_E1mSgL7l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QrbYjDpO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_QrbYjDpO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_fHRAYtoR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_2zCfPnsG_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_1yVWGiP1, 0, m, &cSlice_1yVWGiP1_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_1yVWGiP1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_L46ZrBQv_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_L46ZrBQv_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_vZBPF4Bj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_L46ZrBQv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_L46ZrBQv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_qD707uNE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_blo0l4lg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uKPIeTTN, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_zZhCdl9P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_wnzkx90x, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_crHrnvbB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_U4e6Vp51, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_L7saDiuM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_epQbvpgc, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_Lw2OEt2j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ZX8PNt0i, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_mV0tCJZX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_Dk5oDqXv_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_Dk5oDqXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyF7xYfS, HV_BINOP_DIVIDE, 1, m, &cBinop_QyF7xYfS_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SlRIigtp_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_oEkaUV8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_fFeinfwh_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_T81N6fnh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_oEkaUV8q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fFeinfwh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QyF7xYfS, HV_BINOP_DIVIDE, 0, m, &cBinop_QyF7xYfS_sendMessage);
}

void Heavy_WSTD_EQ::cCast_SlRIigtp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_T81N6fnh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_QyF7xYfS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fYYFxdnc, HV_BINOP_MULTIPLY, 1, m, &cBinop_fYYFxdnc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fYYFxdnc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_1xWdOGH4_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_c3Kq46yA_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_FlHIleNX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Bj1uyKgX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_jqCXKCHz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_mXLeUi4e_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_d8b2CSUJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_Zl2UH28t_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Zl2UH28t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_fYYFxdnc, HV_BINOP_MULTIPLY, 0, m, &cBinop_fYYFxdnc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Uq8gv2xd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_NPDU2Sb9_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_NPDU2Sb9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_odL3eP9q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zPA53lWs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mSYVLC6X, 1, m, &cVar_mSYVLC6X_sendMessage);
}

void Heavy_WSTD_EQ::cVar_mSYVLC6X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0VvDN6RJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_VbV0jT8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ptPGOQ5, HV_BINOP_MULTIPLY, 1, m, &cBinop_4ptPGOQ5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9dIkphm8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_VbV0jT8d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oZUGsFnF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_fPWH4OYO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_fPWH4OYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7CHgnqkW, HV_BINOP_MULTIPLY, 1, m, &cBinop_7CHgnqkW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZIadLj5h_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EgyuTLdY, HV_BINOP_MULTIPLY, 1, m, &cBinop_EgyuTLdY_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_gZnYeCH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_ZIadLj5h_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_uXZRIPlY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NXkwhC2L, HV_BINOP_MULTIPLY, 1, m, &cBinop_NXkwhC2L_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zPkWF2FJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_CHLZ3cJ1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CHLZ3cJ1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n8LmFDbh, HV_BINOP_MULTIPLY, 1, m, &cBinop_n8LmFDbh_sendMessage);
}

void Heavy_WSTD_EQ::cVar_O0MGZfAn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_YL0vjNoJ_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_d8b2CSUJ_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_clQFyNq1_sendMessage);
}

void Heavy_WSTD_EQ::cVar_YAs4T9ih_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Uq8gv2xd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_c3Kq46yA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_jqCXKCHz_sendMessage);
}

void Heavy_WSTD_EQ::cCast_1xWdOGH4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_FlHIleNX_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Bj1uyKgX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Qp0Me2As_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_mXLeUi4e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_LxTANZD4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_CisHBR6b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_mP3W0opV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_odL3eP9q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qaAAV8rG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qaAAV8rG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RcLBBhrh, HV_BINOP_MULTIPLY, 1, m, &cBinop_RcLBBhrh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RcLBBhrh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_bZN3kUiv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_bZN3kUiv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_CisHBR6b_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_0VvDN6RJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_kUQSg8EX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_kUQSg8EX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_r06WDH7J_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P3IuUYoQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_GVEx8FBr_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_E2JDWhMX_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tilrETLj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LvsI8BUh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4ptPGOQ5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_blo0l4lg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_7CHgnqkW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_zZhCdl9P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_EgyuTLdY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_crHrnvbB_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_NXkwhC2L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_L7saDiuM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_n8LmFDbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Lw2OEt2j_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_Gq7H4ICc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YAs4T9ih, 1, m, &cVar_YAs4T9ih_sendMessage);
}

void Heavy_WSTD_EQ::cCast_eIU5Q2eK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_O0MGZfAn, 0, m, &cVar_O0MGZfAn_sendMessage);
}

void Heavy_WSTD_EQ::cCast_E2JDWhMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_EgyuTLdY, HV_BINOP_MULTIPLY, 0, m, &cBinop_EgyuTLdY_sendMessage);
}

void Heavy_WSTD_EQ::cCast_r06WDH7J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_LvsI8BUh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_4ptPGOQ5, HV_BINOP_MULTIPLY, 0, m, &cBinop_4ptPGOQ5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_GVEx8FBr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_NXkwhC2L, HV_BINOP_MULTIPLY, 0, m, &cBinop_NXkwhC2L_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tilrETLj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_7CHgnqkW, HV_BINOP_MULTIPLY, 0, m, &cBinop_7CHgnqkW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P3IuUYoQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_n8LmFDbh, HV_BINOP_MULTIPLY, 0, m, &cBinop_n8LmFDbh_sendMessage);
}

void Heavy_WSTD_EQ::cCast_clQFyNq1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mSYVLC6X, 0, m, &cVar_mSYVLC6X_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YL0vjNoJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_YAs4T9ih, 0, m, &cVar_YAs4T9ih_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6j0cevBG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OG6LsHJq, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_TkgK093t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_uv4xm7Hx, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KWRSI4Sm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_mOppRAfI, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ALTiJ7py_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jOjrOArd, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_7R0SoUJc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_gBKsAU59_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_gBKsAU59_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHQiC2v9, HV_BINOP_DIVIDE, 1, m, &cBinop_dHQiC2v9_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Aak6g6Gf_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_cKywY5hN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_CjsjGHFH_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_aDdzYCQW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_cKywY5hN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_CjsjGHFH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dHQiC2v9, HV_BINOP_DIVIDE, 0, m, &cBinop_dHQiC2v9_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Aak6g6Gf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_aDdzYCQW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_dHQiC2v9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i7QXvhK6, HV_BINOP_MULTIPLY, 1, m, &cBinop_i7QXvhK6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_i7QXvhK6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_FCJrbapa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_qGS9QHFW_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_PZl0V7qT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_i6EfdFiX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_N8z8X412_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_bASQJI68_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_JZqO4E96_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_DeMutXeR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_DeMutXeR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_i7QXvhK6, HV_BINOP_MULTIPLY, 0, m, &cBinop_i7QXvhK6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Hl0TPVB0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_mjruYLUm_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mjruYLUm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fDkaQdbe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_J8GNcLlO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW75zqJX, HV_BINOP_MULTIPLY, 1, m, &cBinop_yW75zqJX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_o6mx2bPz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T3e6w7ra, 1, m, &cVar_T3e6w7ra_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_L5IppPZ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PRh2xAx2, HV_BINOP_MULTIPLY, 1, m, &cBinop_PRh2xAx2_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_6MiiX54U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xwI4S32c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xwI4S32c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qz9LTSpg, HV_BINOP_MULTIPLY, 1, m, &cBinop_Qz9LTSpg_sendMessage);
}

void Heavy_WSTD_EQ::cVar_T3e6w7ra_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ZTsqht0A_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_mzaHSRoZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4ZGSbfl0_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_JZqO4E96_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_G3bNxZgN_sendMessage);
}

void Heavy_WSTD_EQ::cVar_TAMwugwW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Hl0TPVB0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FCJrbapa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_PZl0V7qT_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qGS9QHFW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_N8z8X412_sendMessage);
}

void Heavy_WSTD_EQ::cSend_i6EfdFiX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_pMrL1FYe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_bASQJI68_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zFGQv2q2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_7Q7ZVItO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_T4WcS9zi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_fDkaQdbe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_9sTT6UOv_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_9sTT6UOv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hMsiR1mW, HV_BINOP_MULTIPLY, 1, m, &cBinop_hMsiR1mW_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hMsiR1mW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_7b3Z37u7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_7b3Z37u7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_7Q7ZVItO_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_ZTsqht0A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_SrTsdKZl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_SrTsdKZl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_rsHRbdGv_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_O1FVKzbk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ZHzzi2xG_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xbrBgkzn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_AEbfpOS3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6j0cevBG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yW75zqJX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_TkgK093t_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_PRh2xAx2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KWRSI4Sm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Qz9LTSpg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ALTiJ7py_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_KVv93Gfw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mzaHSRoZ, 0, m, &cVar_mzaHSRoZ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XXn1988S_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TAMwugwW, 1, m, &cVar_TAMwugwW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_G3bNxZgN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_T3e6w7ra, 0, m, &cVar_T3e6w7ra_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4ZGSbfl0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_TAMwugwW, 0, m, &cVar_TAMwugwW_sendMessage);
}

void Heavy_WSTD_EQ::cCast_rsHRbdGv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Qz9LTSpg, HV_BINOP_MULTIPLY, 0, m, &cBinop_Qz9LTSpg_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ZHzzi2xG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yW75zqJX, HV_BINOP_MULTIPLY, 0, m, &cBinop_yW75zqJX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_O1FVKzbk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PRh2xAx2, HV_BINOP_MULTIPLY, 0, m, &cBinop_PRh2xAx2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xbrBgkzn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AEbfpOS3, HV_BINOP_MULTIPLY, 0, m, &cBinop_AEbfpOS3_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_PfMOEbHp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_rInwl1Rj, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_HX94NBQb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_W2FWSlaA, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_GDXQ7khd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OD3BumRf, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_kQNnEpJb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_sfJd1PV4, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_PJ8YJXa4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_UyQ76W9B, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_2x8gGbSm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_saXfjKXE_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_saXfjKXE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqVgaXDx, HV_BINOP_DIVIDE, 1, m, &cBinop_rqVgaXDx_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FnvyFoha_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_EjqVKa1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_zMmcVhWo_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_HiC2P7Rn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_EjqVKa1s_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zMmcVhWo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_rqVgaXDx, HV_BINOP_DIVIDE, 0, m, &cBinop_rqVgaXDx_sendMessage);
}

void Heavy_WSTD_EQ::cCast_FnvyFoha_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HiC2P7Rn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_rqVgaXDx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oQQxa3kU, HV_BINOP_MULTIPLY, 1, m, &cBinop_oQQxa3kU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oQQxa3kU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_wBfW2E9O_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Lc9cVYoW_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_qFHtbAzk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_chBcsKBc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_9m0yj9MJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ILGFlZVW_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3FcOfVt2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_ZBMT5G6I_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ZBMT5G6I_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_oQQxa3kU, HV_BINOP_MULTIPLY, 0, m, &cBinop_oQQxa3kU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_r2xmLK1j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_IofhCytB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IofhCytB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_McPw1wMk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_8vAjFFU1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrXb3uYm, HV_BINOP_MULTIPLY, 1, m, &cBinop_jrXb3uYm_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_EN9yKeFN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_C2SDqdwB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_C2SDqdwB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_8vAjFFU1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_qZaP4rUN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FElb5PhA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FElb5PhA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pBS4wjfH, HV_BINOP_MULTIPLY, 1, m, &cBinop_pBS4wjfH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hrVgFfGN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ouZuXE4b, HV_BINOP_MULTIPLY, 1, m, &cBinop_ouZuXE4b_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_wI2CO59F_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_3V1LU2KL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_3V1LU2KL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_hrVgFfGN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nLfygqic_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lErl8wZT, 1, m, &cVar_lErl8wZT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FF1SFKsI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNcydmKX, HV_BINOP_MULTIPLY, 1, m, &cBinop_gNcydmKX_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_07PGP0AF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_nZI0TFoR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nZI0TFoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UNqLd9g6, HV_BINOP_MULTIPLY, 1, m, &cBinop_UNqLd9g6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_lErl8wZT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j3QWhG7r_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_Cb7Ogbdi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VVJk3jcP_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_3FcOfVt2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VDb7FvDE_sendMessage);
}

void Heavy_WSTD_EQ::cVar_aDLBtaIc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_r2xmLK1j_sendMessage);
}

void Heavy_WSTD_EQ::cCast_wBfW2E9O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_qFHtbAzk_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Lc9cVYoW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_9m0yj9MJ_sendMessage);
}

void Heavy_WSTD_EQ::cSend_chBcsKBc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_wpmw7gzD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ILGFlZVW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_bWWCNyDh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_ftNtY57q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_zC4hqhfQ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_McPw1wMk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_KTtZnPhL_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KTtZnPhL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PHiFo1EA, HV_BINOP_MULTIPLY, 1, m, &cBinop_PHiFo1EA_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PHiFo1EA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_p8aPPuna_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p8aPPuna_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_ftNtY57q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_j3QWhG7r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_hcw8Pj6e_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_hcw8Pj6e_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_phr8qvXx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_BrpNMicc_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_3iUEOTox_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6LzQCgDN_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_jc6ltAiY_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_a3OG2jhr_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jrXb3uYm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PfMOEbHp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_pBS4wjfH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HX94NBQb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_ouZuXE4b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GDXQ7khd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gNcydmKX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kQNnEpJb_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_UNqLd9g6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PJ8YJXa4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_e8Xx62VS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Cb7Ogbdi, 0, m, &cVar_Cb7Ogbdi_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2v6ANncB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aDLBtaIc, 1, m, &cVar_aDLBtaIc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_a3OG2jhr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jrXb3uYm, HV_BINOP_MULTIPLY, 0, m, &cBinop_jrXb3uYm_sendMessage);
}

void Heavy_WSTD_EQ::cCast_3iUEOTox_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gNcydmKX, HV_BINOP_MULTIPLY, 0, m, &cBinop_gNcydmKX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_jc6ltAiY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pBS4wjfH, HV_BINOP_MULTIPLY, 0, m, &cBinop_pBS4wjfH_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BrpNMicc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UNqLd9g6, HV_BINOP_MULTIPLY, 0, m, &cBinop_UNqLd9g6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6LzQCgDN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ouZuXE4b, HV_BINOP_MULTIPLY, 0, m, &cBinop_ouZuXE4b_sendMessage);
}

void Heavy_WSTD_EQ::cCast_phr8qvXx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_VVJk3jcP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_aDLBtaIc, 0, m, &cVar_aDLBtaIc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_VDb7FvDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_lErl8wZT, 0, m, &cVar_lErl8wZT_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g2APUdQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eu4bI2kJ, 1, m, &cIf_eu4bI2kJ_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_fMoPt7OT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_6hX8dSHG, m);
}

void Heavy_WSTD_EQ::cBinop_rLJt5Ujv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fMoPt7OT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_Y6sqa0Om_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_eu4bI2kJ, 0, m, &cIf_eu4bI2kJ_sendMessage);
}

void Heavy_WSTD_EQ::cSwitchcase_6zZCjISx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xE9AAC520: { // "midfreq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_6ISbK9nN, 0, m, &cSlice_6ISbK9nN_sendMessage);
      break;
    }
    default: {
      cSwitchcase_ETvZrjhr_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_6ISbK9nN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_tubFKxVC_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_tubFKxVC_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_Nb0o6iPr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_tubFKxVC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_tubFKxVC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_HLQfaIb3_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_ktyj4tTu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_GTxZ7n1M_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_n4Da5ihH, 0, m, &cIf_n4Da5ihH_sendMessage);
}

void Heavy_WSTD_EQ::cIf_n4Da5ihH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_ferUCm4c_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_qDjrWnYd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_Kg5ldU6j_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_jrbeKzTT_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_U7wlSeMm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_xL497Kso, HV_BINOP_POW, 0, m, &cBinop_xL497Kso_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xL497Kso_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qjGzI0GC, 0, m, &cIf_qjGzI0GC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Df6sdqNm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_XIgLBnAI_sendMessage);
}

void Heavy_WSTD_EQ::cCast_zx4OUGTg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qDjrWnYd, 0, m, &cIf_qDjrWnYd_sendMessage);
}

void Heavy_WSTD_EQ::cCast_xezi2IAP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_Wz2zO0N8_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Wz2zO0N8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qDjrWnYd, 1, m, &cIf_qDjrWnYd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jrbeKzTT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Df6sdqNm_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Kg5ldU6j_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_qjGzI0GC, 0, m, &cIf_qjGzI0GC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XIgLBnAI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xL497Kso, HV_BINOP_POW, 1, m, &cBinop_xL497Kso_sendMessage);
  cMsg_U7wlSeMm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_qjGzI0GC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_pXuK8bqv, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_GTxZ7n1M_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_n4Da5ihH, 1, m, &cIf_n4Da5ihH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ferUCm4c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_ennpCmpv, HV_BINOP_GREATER_THAN, 1, m, &cBinop_ennpCmpv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HhtVHvX4, HV_BINOP_EQ, 1, m, &cBinop_HhtVHvX4_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_LMYTsD1U_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_A8PlNSvn, HV_BINOP_ADD, 0, m, &cBinop_A8PlNSvn_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_A8PlNSvn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_xezi2IAP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zx4OUGTg_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ennpCmpv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_qjGzI0GC, 1, m, &cIf_qjGzI0GC_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_HhtVHvX4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gtZrBzWD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_gtZrBzWD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_pXuK8bqv, m);
}

void Heavy_WSTD_EQ::cCast_yujChPPB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LMYTsD1U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_CDwQU9su_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_A8PlNSvn, HV_BINOP_ADD, 1, m, &cBinop_A8PlNSvn_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_ennpCmpv, HV_BINOP_GREATER_THAN, 0, m, &cBinop_ennpCmpv_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_HhtVHvX4, HV_BINOP_EQ, 0, m, &cBinop_HhtVHvX4_sendMessage);
}

void Heavy_WSTD_EQ::cCast_BiQHxYyM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_ktyj4tTu, 0, m, &cVar_ktyj4tTu_sendMessage);
}

void Heavy_WSTD_EQ::cVar_GeEzdnn6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_hDsZiQrA_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_E1iA1G1B, 0, m, &cIf_E1iA1G1B_sendMessage);
}

void Heavy_WSTD_EQ::cIf_E1iA1G1B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_TjkDJmKt_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_1qva2u6R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_5MPXjs1y_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_ht1WVFE4_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_5eDDB7Wk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Et1jwfOb, HV_BINOP_POW, 0, m, &cBinop_Et1jwfOb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Et1jwfOb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QIlETFvd, 0, m, &cIf_QIlETFvd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Z67sXZYv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_UQDNyvwK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_MGp7Ucss_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_h2TkK2qB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_IttRkvni_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1qva2u6R, 0, m, &cIf_1qva2u6R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_h2TkK2qB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_1qva2u6R, 1, m, &cIf_1qva2u6R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ht1WVFE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_Z67sXZYv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5MPXjs1y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_QIlETFvd, 0, m, &cIf_QIlETFvd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UQDNyvwK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Et1jwfOb, HV_BINOP_POW, 1, m, &cBinop_Et1jwfOb_sendMessage);
  cMsg_5eDDB7Wk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_QIlETFvd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ukqWXPaH_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RU6XGBIY_sendMessage);
      cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_yqxGNDpQ_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_hDsZiQrA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_E1iA1G1B, 1, m, &cIf_E1iA1G1B_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_TjkDJmKt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fhmm1b5g, HV_BINOP_GREATER_THAN, 1, m, &cBinop_Fhmm1b5g_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Mb3RXZ8, HV_BINOP_EQ, 1, m, &cBinop_8Mb3RXZ8_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_f7iSfwDi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_mdOfBpjH, HV_BINOP_ADD, 0, m, &cBinop_mdOfBpjH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mdOfBpjH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_MGp7Ucss_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IttRkvni_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Fhmm1b5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QIlETFvd, 1, m, &cIf_QIlETFvd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_8Mb3RXZ8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_LwWJLdw4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_LwWJLdw4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_ukqWXPaH_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_RU6XGBIY_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.0313f, 0, m, &cBinop_yqxGNDpQ_sendMessage);
}

void Heavy_WSTD_EQ::cCast_7NybhW99_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_GeEzdnn6, 0, m, &cVar_GeEzdnn6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_E3pd0BaY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_f7iSfwDi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_6K7CHKPM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mdOfBpjH, HV_BINOP_ADD, 1, m, &cBinop_mdOfBpjH_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_Fhmm1b5g, HV_BINOP_GREATER_THAN, 0, m, &cBinop_Fhmm1b5g_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_8Mb3RXZ8, HV_BINOP_EQ, 0, m, &cBinop_8Mb3RXZ8_sendMessage);
}

void Heavy_WSTD_EQ::cVar_imZFQ7kG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_cz8tLaDt_sendMessage);
  cIf_onMessage(_c, &Context(_c)->cIf_2Xwquonb, 0, m, &cIf_2Xwquonb_sendMessage);
}

void Heavy_WSTD_EQ::cIf_2Xwquonb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_aI8Tezfp_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cIf_13kY7xFX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cMsg_JWsUpbL5_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 485.0f, 0, m, &cBinop_u4nKsYC7_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cMsg_pGuB1Abf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 10.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvOCwCjO, HV_BINOP_POW, 0, m, &cBinop_IvOCwCjO_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_IvOCwCjO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g8H2YY8R, 0, m, &cIf_g8H2YY8R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g09f30X2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 20.0f, 0, m, &cBinop_vGRv2tze_sendMessage);
}

void Heavy_WSTD_EQ::cCast_ABFeJJ4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_13kY7xFX, 0, m, &cIf_13kY7xFX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_pkPk7JUx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_u5krVbWi_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u5krVbWi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_13kY7xFX, 1, m, &cIf_13kY7xFX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_u4nKsYC7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 100.0f, 0, m, &cBinop_g09f30X2_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_JWsUpbL5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cIf_onMessage(_c, &Context(_c)->cIf_g8H2YY8R, 0, m, &cIf_g8H2YY8R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_vGRv2tze_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_IvOCwCjO, HV_BINOP_POW, 1, m, &cBinop_IvOCwCjO_sendMessage);
  cMsg_pGuB1Abf_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cIf_g8H2YY8R_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_QrGv3kR6, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cBinop_cz8tLaDt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_2Xwquonb, 1, m, &cIf_2Xwquonb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_aI8Tezfp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YY3aVqXs, HV_BINOP_GREATER_THAN, 1, m, &cBinop_YY3aVqXs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MDc1fj3O, HV_BINOP_EQ, 1, m, &cBinop_MDc1fj3O_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_2sfIoU6B_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 100.0f);
  cBinop_onMessage(_c, &Context(_c)->cBinop_yR0fmpzQ, HV_BINOP_ADD, 0, m, &cBinop_yR0fmpzQ_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yR0fmpzQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pkPk7JUx_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_ABFeJJ4O_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YY3aVqXs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_g8H2YY8R, 1, m, &cIf_g8H2YY8R_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_MDc1fj3O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_HN7L9eR2_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_HN7L9eR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_QrGv3kR6, m);
}

void Heavy_WSTD_EQ::cCast_VsJNFQ38_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_imZFQ7kG, 0, m, &cVar_imZFQ7kG_sendMessage);
}

void Heavy_WSTD_EQ::cCast_esUH2LZt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2sfIoU6B_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_SmxXoIoq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yR0fmpzQ, HV_BINOP_ADD, 1, m, &cBinop_yR0fmpzQ_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_YY3aVqXs, HV_BINOP_GREATER_THAN, 0, m, &cBinop_YY3aVqXs_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_MDc1fj3O, HV_BINOP_EQ, 0, m, &cBinop_MDc1fj3O_sendMessage);
}

void Heavy_WSTD_EQ::cIf_QJ0o1Mhy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      sVarf_onMessage(_c, &Context(_c)->sVarf_WveWzeP0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cSwitchcase_T4j6McVc_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x58220DA4: { // "highvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_j54eEfWU, 0, m, &cSlice_j54eEfWU_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LH6eigdx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_j54eEfWU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_Gv7y5Xbg_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_Gv7y5Xbg_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_QHrEB6xm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Gv7y5Xbg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Gv7y5Xbg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_hvqCd7Qh_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_LH6eigdx_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xBDABF734: { // "midvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_qwki8XY7, 0, m, &cSlice_qwki8XY7_sendMessage);
      break;
    }
    default: {
      cSwitchcase_6zZCjISx_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_qwki8XY7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_2sgUBoWX_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_2sgUBoWX_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_bvpBz6Gu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_2sgUBoWX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_2sgUBoWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_sLx33Q4n_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_ETvZrjhr_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x1FF74688: { // "lowvol"
      cSlice_onMessage(_c, &Context(_c)->cSlice_IG16YcMO, 0, m, &cSlice_IG16YcMO_sendMessage);
      break;
    }
    default: {
      cSwitchcase_MSyPzTbP_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_IG16YcMO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_UzNM7pYs_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_UzNM7pYs_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_kOcqlulH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_UzNM7pYs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_UzNM7pYs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_XOTWu2Lk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSwitchcase_MSyPzTbP_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x98D37786: { // "midq"
      cSlice_onMessage(_c, &Context(_c)->cSlice_5LavL4mZ, 0, m, &cSlice_5LavL4mZ_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_EQ::cSlice_5LavL4mZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NXY9kEKx_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NXY9kEKx_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_EQ::cVar_35Hg1E5b_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NXY9kEKx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_NXY9kEKx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_j5UHVjtT_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_uzRqW2WD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_gfl1TidP, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_c7X3O1C5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_2UKSoCYt, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_0nIZa7xg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_SeC5DtSd, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_KCTUSGwk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_KOD0zgCc, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_GY8gAXZw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_IWkqPl0x, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_SFEwzws8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fjrWZ2wj_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_fjrWZ2wj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L8OmIhT8, HV_BINOP_DIVIDE, 1, m, &cBinop_L8OmIhT8_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8hijTCki_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_nJvC44Is_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_6LZ0hDqv_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_5EqO3mLF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_nJvC44Is_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6LZ0hDqv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_L8OmIhT8, HV_BINOP_DIVIDE, 0, m, &cBinop_L8OmIhT8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8hijTCki_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_5EqO3mLF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_L8OmIhT8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pz9W3xqI, HV_BINOP_MULTIPLY, 1, m, &cBinop_pz9W3xqI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pz9W3xqI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_YFpS446s_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lS8Uz41X_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_TnIRrliW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Y3dqrdqA_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_nEIMV5Mc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_97RiOha0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_n1F5q0I1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_qoLGnecd_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qoLGnecd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_pz9W3xqI, HV_BINOP_MULTIPLY, 0, m, &cBinop_pz9W3xqI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Ie7yqht7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_4uE2uZwI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4uE2uZwI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uOfHyBCx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_RpAQVHUA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PK5dvQ6G, 1, m, &cVar_PK5dvQ6G_sendMessage);
}

void Heavy_WSTD_EQ::cVar_PK5dvQ6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_F1ZFJxmX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_tWUAOIVG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5QhIo8QK, HV_BINOP_MULTIPLY, 1, m, &cBinop_5QhIo8QK_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QXYZqxc4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_tWUAOIVG_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yAt75JiA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_2KikxoZe_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_2KikxoZe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFmYMSwR, HV_BINOP_MULTIPLY, 1, m, &cBinop_xFmYMSwR_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_I47DIXMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3rj1PVUp, HV_BINOP_MULTIPLY, 1, m, &cBinop_3rj1PVUp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_iiVpZJph_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_I47DIXMN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zsUKEb76_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MYKXbix2, HV_BINOP_MULTIPLY, 1, m, &cBinop_MYKXbix2_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_zdJazS02_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_FlfPxyC1_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_FlfPxyC1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQiC1v8p, HV_BINOP_MULTIPLY, 1, m, &cBinop_gQiC1v8p_sendMessage);
}

void Heavy_WSTD_EQ::cVar_Ea2YNFY8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_9u8bsIWV_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_n1F5q0I1_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_hhl9a4eT_sendMessage);
}

void Heavy_WSTD_EQ::cVar_3TuTX6KM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Ie7yqht7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lS8Uz41X_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_nEIMV5Mc_sendMessage);
}

void Heavy_WSTD_EQ::cCast_YFpS446s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_TnIRrliW_sendMessage);
}

void Heavy_WSTD_EQ::cSend_Y3dqrdqA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_Lyejhmvr_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_97RiOha0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_5r1SmZwm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_wb5SGBQK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_s80JItwN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_uOfHyBCx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oxNF8Fp6_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_oxNF8Fp6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p5HFPYw5, HV_BINOP_MULTIPLY, 1, m, &cBinop_p5HFPYw5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_p5HFPYw5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_cunFmX14_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cunFmX14_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_wb5SGBQK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_F1ZFJxmX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_G07FnVHM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_G07FnVHM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_OWH28gTQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_P1cbaJ7G_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_uk0ZHmoF_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_cxTM3GIP_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_lfdiRRkQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JlJJOj9x_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_5QhIo8QK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_uzRqW2WD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_xFmYMSwR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_c7X3O1C5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_3rj1PVUp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_0nIZa7xg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_MYKXbix2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_KCTUSGwk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_gQiC1v8p_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GY8gAXZw_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_W39B8ON7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3TuTX6KM, 1, m, &cVar_3TuTX6KM_sendMessage);
}

void Heavy_WSTD_EQ::cCast_t9Sx512z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Ea2YNFY8, 0, m, &cVar_Ea2YNFY8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_lfdiRRkQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_xFmYMSwR, HV_BINOP_MULTIPLY, 0, m, &cBinop_xFmYMSwR_sendMessage);
}

void Heavy_WSTD_EQ::cCast_P1cbaJ7G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_gQiC1v8p, HV_BINOP_MULTIPLY, 0, m, &cBinop_gQiC1v8p_sendMessage);
}

void Heavy_WSTD_EQ::cCast_cxTM3GIP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_3rj1PVUp, HV_BINOP_MULTIPLY, 0, m, &cBinop_3rj1PVUp_sendMessage);
}

void Heavy_WSTD_EQ::cCast_OWH28gTQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_JlJJOj9x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_5QhIo8QK, HV_BINOP_MULTIPLY, 0, m, &cBinop_5QhIo8QK_sendMessage);
}

void Heavy_WSTD_EQ::cCast_uk0ZHmoF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_MYKXbix2, HV_BINOP_MULTIPLY, 0, m, &cBinop_MYKXbix2_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hhl9a4eT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PK5dvQ6G, 0, m, &cVar_PK5dvQ6G_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9u8bsIWV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_3TuTX6KM, 0, m, &cVar_3TuTX6KM_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_lLdQoIE4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ugu5BkdW, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_YPXEPceG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_URLplXrp, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_jna5qhMx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_5vfYu8yo, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_9VMOBUVV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_jjUIYe6a, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_eXGsdwDe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_7WGxeMfB_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_7WGxeMfB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g73q3Dun, HV_BINOP_DIVIDE, 1, m, &cBinop_g73q3Dun_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_nspQ5PVI_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_aHVLKC8d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_cT2iUPHx_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_kHG47VDk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_aHVLKC8d_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_cT2iUPHx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_g73q3Dun, HV_BINOP_DIVIDE, 0, m, &cBinop_g73q3Dun_sendMessage);
}

void Heavy_WSTD_EQ::cCast_nspQ5PVI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_kHG47VDk_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_g73q3Dun_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v0IAk2td, HV_BINOP_MULTIPLY, 1, m, &cBinop_v0IAk2td_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_v0IAk2td_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_UPxXuWR2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Fly1yzJq_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_PsNDykz6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_x7lmrZCg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_hBQgRfWB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Rh6oqgtM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_iJzB17la_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_g0KU0Kjj_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g0KU0Kjj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_v0IAk2td, HV_BINOP_MULTIPLY, 0, m, &cBinop_v0IAk2td_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Wsj28iB8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_tKZTP88Q_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_tKZTP88Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xDoe9NvZ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_jY7cTmik_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mrKkGhB7, HV_BINOP_MULTIPLY, 1, m, &cBinop_mrKkGhB7_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xYpYMzrN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uPZXWPWX, 1, m, &cVar_uPZXWPWX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_B1rZuNyw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_de7Tm6Jq, HV_BINOP_MULTIPLY, 1, m, &cBinop_de7Tm6Jq_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_XVxhhTSF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_OYanjTAt_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OYanjTAt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvMOCBLA, HV_BINOP_MULTIPLY, 1, m, &cBinop_zvMOCBLA_sendMessage);
}

void Heavy_WSTD_EQ::cVar_uPZXWPWX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_r9MsNj5P_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_zd59JvM1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4YfKmNYO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_iJzB17la_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_XbRygMti_sendMessage);
}

void Heavy_WSTD_EQ::cVar_PqhRmMpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_Wsj28iB8_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Fly1yzJq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_hBQgRfWB_sendMessage);
}

void Heavy_WSTD_EQ::cCast_UPxXuWR2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_PsNDykz6_sendMessage);
}

void Heavy_WSTD_EQ::cSend_x7lmrZCg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_iY3f9nll_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Rh6oqgtM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_b4hTE4zN_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_QS7oUMNR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_VpcZjU5G_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_xDoe9NvZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_qygkkjWu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_qygkkjWu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrYM0rUM, HV_BINOP_MULTIPLY, 1, m, &cBinop_yrYM0rUM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_yrYM0rUM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_zAJyA9yp_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zAJyA9yp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_QS7oUMNR_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_r9MsNj5P_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_pVnGzff3_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_pVnGzff3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_8EqfbjrL_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_9Ai3RRF2_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Whd3x6c6_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_LN6wBRN5_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Rn46xoJL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lLdQoIE4_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_mrKkGhB7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_YPXEPceG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_de7Tm6Jq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_jna5qhMx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_zvMOCBLA_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9VMOBUVV_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_mgPasiUr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zd59JvM1, 0, m, &cVar_zd59JvM1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_tMAvOG5n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PqhRmMpu, 1, m, &cVar_PqhRmMpu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_XbRygMti_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uPZXWPWX, 0, m, &cVar_uPZXWPWX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_4YfKmNYO_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_PqhRmMpu, 0, m, &cVar_PqhRmMpu_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8EqfbjrL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zvMOCBLA, HV_BINOP_MULTIPLY, 0, m, &cBinop_zvMOCBLA_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Whd3x6c6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_mrKkGhB7, HV_BINOP_MULTIPLY, 0, m, &cBinop_mrKkGhB7_sendMessage);
}

void Heavy_WSTD_EQ::cCast_9Ai3RRF2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_de7Tm6Jq, HV_BINOP_MULTIPLY, 0, m, &cBinop_de7Tm6Jq_sendMessage);
}

void Heavy_WSTD_EQ::cCast_LN6wBRN5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rn46xoJL, HV_BINOP_MULTIPLY, 0, m, &cBinop_Rn46xoJL_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_WGDbwMu9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QKRYGvSF, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_p6vgK9tP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ERvQ8CKz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_smWmTwh8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_v1n7YWVC, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_ssLE7xSI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_CCkpORTi, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_fwTacwTX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 10.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_BMQraApz, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_N8EaXkFb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_xV0EJKFi_sendMessage);
}

void Heavy_WSTD_EQ::cSystem_xV0EJKFi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DBcVbrQ0, HV_BINOP_DIVIDE, 1, m, &cBinop_DBcVbrQ0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_8d73lgbh_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_IlWzwxcb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 8.0f, 0, m, &cBinop_4z4saje5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_x24lPDGD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cUnop_onMessage(_c, HV_UNOP_ATAN, m, &cUnop_IlWzwxcb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_4z4saje5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_DBcVbrQ0, HV_BINOP_DIVIDE, 0, m, &cBinop_DBcVbrQ0_sendMessage);
}

void Heavy_WSTD_EQ::cCast_8d73lgbh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_x24lPDGD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_DBcVbrQ0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UBDn9OKV, HV_BINOP_MULTIPLY, 1, m, &cBinop_UBDn9OKV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UBDn9OKV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6fAKNjmj_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_gVgKRYyC_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_EJy3obJe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_nbcS2i1s_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cUnop_GQRys0Bk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_Sq43a3mG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_XQr3qUd2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 20.0f, 0, m, &cBinop_mjmLQY8c_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_mjmLQY8c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_UBDn9OKV, HV_BINOP_MULTIPLY, 0, m, &cBinop_UBDn9OKV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_XLwwgmlP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.1f, 0, m, &cBinop_UZbpDP2E_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UZbpDP2E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_suWATZXI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_6fvEYUCb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zobaHYH1, HV_BINOP_MULTIPLY, 1, m, &cBinop_zobaHYH1_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_Jq8JatfX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Tj0vsmBB_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_Tj0vsmBB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6fvEYUCb_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_h9lrMtMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_xTRY79fN_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_xTRY79fN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AiPkpFjX, HV_BINOP_MULTIPLY, 1, m, &cBinop_AiPkpFjX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6zipB14D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bKDaFmr5, HV_BINOP_MULTIPLY, 1, m, &cBinop_bKDaFmr5_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_ybUmoPUV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_g17Z18Bb_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_g17Z18Bb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_6zipB14D_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_KugwbYqG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E6r3I2TX, 1, m, &cVar_E6r3I2TX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YzNEm1jm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9yRG6AFr, HV_BINOP_MULTIPLY, 1, m, &cBinop_9yRG6AFr_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_LdjQjgoP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_q2ciezr0_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_q2ciezr0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F5laAcl6, HV_BINOP_MULTIPLY, 1, m, &cBinop_F5laAcl6_sendMessage);
}

void Heavy_WSTD_EQ::cVar_E6r3I2TX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_6gtCftrG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cVar_dOWLAjsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CMp5N4eh_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 20000.0f, 0, m, &cBinop_XQr3qUd2_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_qTPsmxhM_sendMessage);
}

void Heavy_WSTD_EQ::cVar_NZN9fqe6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 100.0f, 0, m, &cBinop_XLwwgmlP_sendMessage);
}

void Heavy_WSTD_EQ::cCast_6fAKNjmj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SIN, m, &cUnop_EJy3obJe_sendMessage);
}

void Heavy_WSTD_EQ::cCast_gVgKRYyC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_COS, m, &cUnop_GQRys0Bk_sendMessage);
}

void Heavy_WSTD_EQ::cSend_nbcS2i1s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_ySiLqefx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_Sq43a3mG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_JNx0OaIt_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cSend_sFrKhoPP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_eSVrN1i8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_suWATZXI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_RxcOy1LX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_RxcOy1LX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YMzqI3Xh, HV_BINOP_MULTIPLY, 1, m, &cBinop_YMzqI3Xh_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_YMzqI3Xh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_UEuV2Yau_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_UEuV2Yau_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_sFrKhoPP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_6gtCftrG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_0VqoNtoc_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_0VqoNtoc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EiKZ8cFQ_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_2RC5P5m1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_plNZgmEa_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_piL8sidk_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_R6J1oeg7_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_u2B4gWKM_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_zobaHYH1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_WGDbwMu9_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_AiPkpFjX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_p6vgK9tP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_bKDaFmr5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_smWmTwh8_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_9yRG6AFr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ssLE7xSI_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_F5laAcl6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fwTacwTX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cCast_85VjVMCK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_dOWLAjsr, 0, m, &cVar_dOWLAjsr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_O2eEn830_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NZN9fqe6, 1, m, &cVar_NZN9fqe6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_R6J1oeg7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AiPkpFjX, HV_BINOP_MULTIPLY, 0, m, &cBinop_AiPkpFjX_sendMessage);
}

void Heavy_WSTD_EQ::cCast_plNZgmEa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_9yRG6AFr, HV_BINOP_MULTIPLY, 0, m, &cBinop_9yRG6AFr_sendMessage);
}

void Heavy_WSTD_EQ::cCast_piL8sidk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_bKDaFmr5, HV_BINOP_MULTIPLY, 0, m, &cBinop_bKDaFmr5_sendMessage);
}

void Heavy_WSTD_EQ::cCast_2RC5P5m1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_F5laAcl6, HV_BINOP_MULTIPLY, 0, m, &cBinop_F5laAcl6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_u2B4gWKM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_zobaHYH1, HV_BINOP_MULTIPLY, 0, m, &cBinop_zobaHYH1_sendMessage);
}

void Heavy_WSTD_EQ::cCast_EiKZ8cFQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
}

void Heavy_WSTD_EQ::cCast_CMp5N4eh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_NZN9fqe6, 0, m, &cVar_NZN9fqe6_sendMessage);
}

void Heavy_WSTD_EQ::cCast_qTPsmxhM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_E6r3I2TX, 0, m, &cVar_E6r3I2TX_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_ukqWXPaH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QJ0o1Mhy, 1, m, &cIf_QJ0o1Mhy_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_bszwisbi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  sVarf_onMessage(_c, &Context(_c)->sVarf_WveWzeP0, m);
}

void Heavy_WSTD_EQ::cBinop_RU6XGBIY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bszwisbi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cBinop_yqxGNDpQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_QJ0o1Mhy, 0, m, &cIf_QJ0o1Mhy_sendMessage);
}

void Heavy_WSTD_EQ::cVar_1g03iaMu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_OXkWP8Cg, HV_BINOP_DIVIDE, 0, m, &cBinop_OXkWP8Cg_sendMessage);
}

void Heavy_WSTD_EQ::cVar_KYp0bA6d_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QWCp7tZb, HV_BINOP_DIVIDE, 1, m, &cBinop_QWCp7tZb_sendMessage);
  cBinop_onMessage(_c, &Context(_c)->cBinop_OXkWP8Cg, HV_BINOP_DIVIDE, 1, m, &cBinop_OXkWP8Cg_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_7qqN8heI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nRNQUTVw, HV_BINOP_DIVIDE, 0, m, &cBinop_nRNQUTVw_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_1A1ef6dV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_nRNQUTVw, HV_BINOP_DIVIDE, 1, m, &cBinop_nRNQUTVw_sendMessage);
}

void Heavy_WSTD_EQ::cCast_Efe9vPp8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KYp0bA6d, 0, m, &cVar_KYp0bA6d_sendMessage);
}

void Heavy_WSTD_EQ::cCast_hioccl7c_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_QWCp7tZb, HV_BINOP_DIVIDE, 0, m, &cBinop_QWCp7tZb_sendMessage);
}

void Heavy_WSTD_EQ::cCast_5KeQMvM0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_1g03iaMu, 0, m, &cVar_1g03iaMu_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_QWCp7tZb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_7qqN8heI_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_OXkWP8Cg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_LOG, m, &cUnop_1A1ef6dV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_nRNQUTVw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_6wPlivqT_sendMessage);
}

void Heavy_WSTD_EQ::cUnop_1pHyu2zH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 0.313f, 0, m, &cBinop_jEAZI9bU_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_JhixydJl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.313f, 0, m, &cBinop_PwT6U3QV_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_6wPlivqT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_JhixydJl_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_PwT6U3QV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_ABS, m, &cUnop_1pHyu2zH_sendMessage);
}

void Heavy_WSTD_EQ::cBinop_jEAZI9bU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3zyuwkjg_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cMsg_K1NuEw5k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "highvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jXcnRuar_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_T4j6McVc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_5R954XtI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jXcnRuar_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_T4j6McVc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_42vSJ2BE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "lowvol");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jXcnRuar_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_T4j6McVc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_EsZoqUpI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midfreq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jXcnRuar_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_T4j6McVc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_3zyuwkjg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "midq");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_jXcnRuar_onMessage(_c, NULL, 0, m, NULL);
  cSwitchcase_T4j6McVc_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_EQ::cMsg_pzaJPnFM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1337.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_CG738qBI, 0, m, &cVar_CG738qBI_sendMessage);
}

void Heavy_WSTD_EQ::cMsg_3Dur9i1O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.0f);
  cVar_onMessage(_c, &Context(_c)->cVar_xWf7UZvh, 0, m, &cVar_xWf7UZvh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_01G6K7PO, 0, m, &cVar_01G6K7PO_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_n8DxDHoG, 0, m, &cVar_n8DxDHoG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_M2litCOk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_xWf7UZvh, 0, m, &cVar_xWf7UZvh_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_OBCdIMwd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_01G6K7PO, 0, m, &cVar_01G6K7PO_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_hLfXSO79_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_n8DxDHoG, 0, m, &cVar_n8DxDHoG_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_sKOIdPwz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_mzaHSRoZ, 0, m, &cVar_mzaHSRoZ_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_qD707uNE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_XXn1988S_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_KVv93Gfw_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_R0V7U4Bg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_Y5r2kgZz_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_7GsSDsRM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_5BjHHkYm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_fHRAYtoR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_g9gwh5P3_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_nlVRgIsN_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ziJH9D3X_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_pxhbOd5g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_DqhTUj4a_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_TLyEhk9q_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_06UpQNKN_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bDG4gBAp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_mV0tCJZX_sendMessage(_c, 0, m);
  cMsg_7R0SoUJc_sendMessage(_c, 0, m);
  cMsg_2x8gGbSm_sendMessage(_c, 0, m);
  cMsg_SFEwzws8_sendMessage(_c, 0, m);
  cMsg_eXGsdwDe_sendMessage(_c, 0, m);
  cMsg_N8EaXkFb_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_O0MGZfAn, 0, m, &cVar_O0MGZfAn_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_mzaHSRoZ, 0, m, &cVar_mzaHSRoZ_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Cb7Ogbdi, 0, m, &cVar_Cb7Ogbdi_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Ea2YNFY8, 0, m, &cVar_Ea2YNFY8_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_zd59JvM1, 0, m, &cVar_zd59JvM1_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_dOWLAjsr, 0, m, &cVar_dOWLAjsr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_1ykegNop, 0, m, &cVar_1ykegNop_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_MiRisBSP, 0, m, &cVar_MiRisBSP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_hic5jfvC, 0, m, &cVar_hic5jfvC_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_5fNhFnIP, 0, m, &cVar_5fNhFnIP_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_wHOpbdTl, 0, m, &cVar_wHOpbdTl_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_IFEA1uAM, 0, m, &cVar_IFEA1uAM_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_E1mSgL7l, 0, m, &cVar_E1mSgL7l_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_vZBPF4Bj, 0, m, &cVar_vZBPF4Bj_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Nb0o6iPr, 0, m, &cVar_Nb0o6iPr_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_ktyj4tTu, 0, m, &cVar_ktyj4tTu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_GeEzdnn6, 0, m, &cVar_GeEzdnn6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_imZFQ7kG, 0, m, &cVar_imZFQ7kG_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_QHrEB6xm, 0, m, &cVar_QHrEB6xm_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_bvpBz6Gu, 0, m, &cVar_bvpBz6Gu_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_kOcqlulH, 0, m, &cVar_kOcqlulH_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_35Hg1E5b, 0, m, &cVar_35Hg1E5b_sendMessage);
  cMsg_3Dur9i1O_sendMessage(_c, 0, m);
  cMsg_pzaJPnFM_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_Qp0Me2As_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_RcLBBhrh, HV_BINOP_MULTIPLY, 0, m, &cBinop_RcLBBhrh_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_LxTANZD4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_9dIkphm8_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_oZUGsFnF_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_gZnYeCH1_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_uXZRIPlY_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_mP3W0opV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_zPA53lWs_sendMessage);
  cMsg_zPkWF2FJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_pMrL1FYe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_hMsiR1mW, HV_BINOP_MULTIPLY, 0, m, &cBinop_hMsiR1mW_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_zFGQv2q2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_L5IppPZ0_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_T4WcS9zi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AEbfpOS3, HV_BINOP_MULTIPLY, 1, m, &cBinop_AEbfpOS3_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_J8GNcLlO_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_o6mx2bPz_sendMessage);
  cMsg_6MiiX54U_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_wpmw7gzD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PHiFo1EA, HV_BINOP_MULTIPLY, 0, m, &cBinop_PHiFo1EA_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_bWWCNyDh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_EN9yKeFN_sendMessage(_c, 0, m);
  cMsg_qZaP4rUN_sendMessage(_c, 0, m);
  cMsg_wI2CO59F_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_FF1SFKsI_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_zC4hqhfQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_nLfygqic_sendMessage);
  cMsg_07PGP0AF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_HLQfaIb3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_zd59JvM1, 0, m, &cVar_zd59JvM1_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_j5UHVjtT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_tMAvOG5n_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_mgPasiUr_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_hvqCd7Qh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_BiQHxYyM_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_CDwQU9su_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_yujChPPB_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_XOTWu2Lk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_VsJNFQ38_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_SmxXoIoq_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_esUH2LZt_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_sLx33Q4n_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_7NybhW99_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_6K7CHKPM_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_E3pd0BaY_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_Lyejhmvr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_p5HFPYw5, HV_BINOP_MULTIPLY, 0, m, &cBinop_p5HFPYw5_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_5r1SmZwm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_QXYZqxc4_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_yAt75JiA_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_iiVpZJph_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_zsUKEb76_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_s80JItwN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_RpAQVHUA_sendMessage);
  cMsg_zdJazS02_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_iY3f9nll_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_yrYM0rUM, HV_BINOP_MULTIPLY, 0, m, &cBinop_yrYM0rUM_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_b4hTE4zN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_B1rZuNyw_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_VpcZjU5G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_Rn46xoJL, HV_BINOP_MULTIPLY, 1, m, &cBinop_Rn46xoJL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_jY7cTmik_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_xYpYMzrN_sendMessage);
  cMsg_XVxhhTSF_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_ySiLqefx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_YMzqI3Xh, HV_BINOP_MULTIPLY, 0, m, &cBinop_YMzqI3Xh_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_JNx0OaIt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Jq8JatfX_sendMessage(_c, 0, m);
  cMsg_h9lrMtMt_sendMessage(_c, 0, m);
  cMsg_ybUmoPUV_sendMessage(_c, 0, m);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -2.0f, 0, m, &cBinop_YzNEm1jm_sendMessage);
}

void Heavy_WSTD_EQ::cReceive_eSVrN1i8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_KugwbYqG_sendMessage);
  cMsg_LdjQjgoP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_EQ::cReceive_G6i3dsJC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_CG738qBI, 0, m, &cVar_CG738qBI_sendMessage);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_EQ::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6, Bf7, Bf8;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_varread_f(&sVarf_l8XAI5VV, VOf(Bf0));
    __hv_varread_f(&sVarf_JW4b0eCX, VOf(Bf1));
    __hv_varread_f(&sVarf_conjrBqP, VOf(Bf2));
    __hv_add_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_add_f(VIf(Bf0), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_8mD5mv66, VOf(Bf0));
    __hv_varread_f(&sVarf_jun1Y1Bj, VOf(Bf1));
    __hv_varread_f(&sVarf_pyrQPrPa, VOf(Bf3));
    __hv_add_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_add_f(VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_uKPIeTTN, VOf(Bf0));
    __hv_line_f(&sLine_wnzkx90x, VOf(Bf1));
    __hv_line_f(&sLine_U4e6Vp51, VOf(Bf4));
    __hv_line_f(&sLine_epQbvpgc, VOf(Bf5));
    __hv_line_f(&sLine_ZX8PNt0i, VOf(Bf6));
    __hv_biquad_f(&sBiquad_s_MfW9JfUK, VIf(I0), VIf(Bf0), VIf(Bf1), VIf(Bf4), VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_mVOkfkPc, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_line_f(&sLine_OG6LsHJq, VOf(Bf6));
    __hv_zero_f(VOf(Bf4));
    __hv_line_f(&sLine_uv4xm7Hx, VOf(Bf1));
    __hv_line_f(&sLine_mOppRAfI, VOf(Bf0));
    __hv_line_f(&sLine_jOjrOArd, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_IXgJlKeF, VIf(I0), VIf(Bf6), VIf(Bf4), VIf(Bf1), VIf(Bf0), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_6hX8dSHG, VOf(Bf0));
    __hv_mul_f(VIf(Bf7), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_rInwl1Rj, VOf(Bf7));
    __hv_line_f(&sLine_W2FWSlaA, VOf(Bf1));
    __hv_line_f(&sLine_OD3BumRf, VOf(Bf4));
    __hv_line_f(&sLine_sfJd1PV4, VOf(Bf6));
    __hv_line_f(&sLine_UyQ76W9B, VOf(Bf8));
    __hv_biquad_f(&sBiquad_s_mY4z2avg, VIf(I0), VIf(Bf7), VIf(Bf1), VIf(Bf4), VIf(Bf6), VIf(Bf8), VOf(Bf8));
    __hv_varread_f(&sVarf_wXG7r5LV, VOf(Bf6));
    __hv_mul_f(VIf(Bf8), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_l8XAI5VV, VIf(Bf5));
    __hv_varwrite_f(&sVarf_JW4b0eCX, VIf(Bf0));
    __hv_varwrite_f(&sVarf_conjrBqP, VIf(Bf6));
    __hv_line_f(&sLine_gfl1TidP, VOf(Bf6));
    __hv_line_f(&sLine_2UKSoCYt, VOf(Bf0));
    __hv_line_f(&sLine_SeC5DtSd, VOf(Bf5));
    __hv_line_f(&sLine_KOD0zgCc, VOf(Bf8));
    __hv_line_f(&sLine_IWkqPl0x, VOf(Bf4));
    __hv_biquad_f(&sBiquad_s_dgTIEzGe, VIf(I1), VIf(Bf6), VIf(Bf0), VIf(Bf5), VIf(Bf8), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_pXuK8bqv, VOf(Bf8));
    __hv_mul_f(VIf(Bf4), VIf(Bf8), VOf(Bf8));
    __hv_line_f(&sLine_ugu5BkdW, VOf(Bf4));
    __hv_zero_f(VOf(Bf5));
    __hv_line_f(&sLine_URLplXrp, VOf(Bf0));
    __hv_line_f(&sLine_5vfYu8yo, VOf(Bf6));
    __hv_line_f(&sLine_jjUIYe6a, VOf(Bf1));
    __hv_biquad_f(&sBiquad_s_f8zli3sR, VIf(I1), VIf(Bf4), VIf(Bf5), VIf(Bf0), VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_WveWzeP0, VOf(Bf6));
    __hv_mul_f(VIf(Bf1), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_QKRYGvSF, VOf(Bf1));
    __hv_line_f(&sLine_ERvQ8CKz, VOf(Bf0));
    __hv_line_f(&sLine_v1n7YWVC, VOf(Bf5));
    __hv_line_f(&sLine_CCkpORTi, VOf(Bf4));
    __hv_line_f(&sLine_BMQraApz, VOf(Bf7));
    __hv_biquad_f(&sBiquad_s_BzDxoZ4N, VIf(I1), VIf(Bf1), VIf(Bf0), VIf(Bf5), VIf(Bf4), VIf(Bf7), VOf(Bf7));
    __hv_varread_f(&sVarf_QrGv3kR6, VOf(Bf4));
    __hv_mul_f(VIf(Bf7), VIf(Bf4), VOf(Bf4));
    __hv_varwrite_f(&sVarf_8mD5mv66, VIf(Bf8));
    __hv_varwrite_f(&sVarf_jun1Y1Bj, VIf(Bf6));
    __hv_varwrite_f(&sVarf_pyrQPrPa, VIf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(O1), VOf(O1));
    __hv_add_f(VIf(Bf2), VIf(O0), VOf(O0));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_EQ::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_EQ::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
